<?php
/**
 * Business Roy functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Business Roy
 */
if ( ! function_exists( 'business_roy_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function business_roy_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Business Roy, use a find and replace
		 * to change 'business-roy' to the name of your theme in all the template files.
		 */

		load_theme_textdomain( 'business-roy', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		add_theme_support( "wp-block-styles" );

		add_theme_support( "responsive-embeds" );

		add_theme_support( "align-wide" );

		add_theme_support('custom-line-height');
 
		add_theme_support('custom-spacing');

		add_theme_support('custom-units');

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		
		/**
		 * Enable support for post formats
		 *
		 * @link https://developer.wordpress.org/themes/functionality/post-formats/
		 */
		add_theme_support( 'post-formats', array( 'gallery', 'quote', 'audio', 'image', 'video' ) );
		
		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1'  => esc_html__( 'Primary Menu', 'business-roy' ),
			'menu-2'  => esc_html__( 'Top Menu', 'business-roy' )
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'business_roy_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Experimental support for adding blocks inside nav menus
		add_theme_support( 'block-nav-menus' );

		// Add support for experimental link color control.
		add_theme_support( 'experimental-link-color' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'business_roy_setup' );


/**
 * Enqueue admin (custom-editor-style) styles.
*/
function business_roy_admin_editor_style() {
	add_editor_style( get_stylesheet_directory_uri() . '/custom-editor-style.css', array(), date( 'Ymd-Gis', filemtime( get_theme_file_path( 'style.css' ) ) ) );
}
add_action( 'admin_init', 'business_roy_admin_editor_style' );

/**
 * Enqueue admin styles.
*/
function business_roy_admin_scripts() {

	$deps = array();

	// FontAwesome icon function
	business_roy_dynamic_fonts();
	wp_enqueue_style( 'business-roy-admin-style', get_stylesheet_directory_uri() . '/assets/css/admin-style.css', $deps, date( 'Ymd-Gis', filemtime( get_theme_file_path( 'style.css' ) ) ) );

}
add_action( 'register_block_style', 'business_roy_admin_scripts' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function business_roy_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Right Widget Sidebar Area', 'business-roy' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'business-roy' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	));
	register_sidebar( array(
		'name'          => esc_html__( 'Left Widget Sidebar Area', 'business-roy' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'Add widgets here.', 'business-roy' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	));

	register_sidebar( array(
		'name'          => esc_html__( 'Menu Popup Sidebar', 'business-roy' ),
		'id'            => 'menu-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'business-roy' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	));

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area', 'business-roy' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here.', 'business-roy' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	));
	
}
add_action( 'widgets_init', 'business_roy_widgets_init' );


if ( ! function_exists( 'business_roy_fonts_url' ) ) :
	/**
	 * Register Google fonts for Business Roy
	 *
	 * Create your own business_roy_fonts_url() function to override in a child theme.
	 *
	 * @since Business Roy 1.0.0
	 *
	 * @return string Google fonts URL for the theme.
	 */
    function business_roy_fonts_url() {
        $fonts_url = '';

		/* Translators: If there are characters in your language that are not
		* supported by Poppins, translate this to 'off'. Do not translate
		* into your own language.
		*/
		$body_fonts = get_theme_mod('body_font_family');

		if( $body_fonts == 'Poppins'):
			$font_families[] = 'Poppins:wght@200;300;400;500;600;700&display=swap';
		endif;
		
		if( $body_fonts == 'Roboto'):
			$font_families[] = 'Roboto:wght@400;500;600;700;800&display=swap';
		endif;
		
		if( $body_fonts == 'Raleway'):
			$font_families[] = 'Raleway:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,500;1,600&display=swap';
		endif;

		if( $body_fonts == 'Montserrat'):
			$font_families[] = 'Montserrat:ital,wght@0,100;0,200;0,300;1,100;1,200;1,300&display=swap';
		endif;

		if( $body_fonts == 'Arizonia'):
			$font_families[] = 'Arizonia&display=swap';
		endif;


		if ( ! empty( $font_families ) ) {

			$query_args = array(
				'family' => implode( '&family=', $font_families ), 
				'display' => 'swap',
			);

			$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css2' );
		}

		return $fonts_url;

    }
endif;
/**
 * Enqueue scripts and styles.
 */
function business_roy_scripts() {

	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	$debugmode = defined( 'WP_DEBUG' ) && WP_DEBUG ? 'true' : '';

	/** Load Font Family */
	wp_enqueue_style( 'business-roy-fonts', business_roy_fonts_url(), array(), null );
	
	// Icon function
	business_roy_dynamic_fonts();
	
	wp_enqueue_style( 'dashicons' );

	if( $debugmode == true ){
		/** Load Js Script */
		wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/assets/js/owl.carousel.js', array('jquery'),'2.3.4', true );
		wp_enqueue_script( 'YTPlayer', get_template_directory_uri() . '/assets/js/jquery.mb.YTPlayer.js', array('jquery'), true);
		wp_enqueue_script( 'jquery-prettyPhoto', get_template_directory_uri() . '/assets/js/jquery.prettyPhoto.js', array(), '3.1.6', true);
		wp_enqueue_script( 'aos-animation', get_template_directory_uri() . '/assets/js/aos.js', array('jquery'), true );
		wp_enqueue_script( 'waypoints', get_template_directory_uri() . '/assets/js/waypoints.js', array('jquery'), true );	
		wp_enqueue_script( 'counter', get_template_directory_uri() . '/assets/js/jquery.counterup.js', array('jquery'), true );
		wp_enqueue_script( 'navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(),  true );
		wp_enqueue_script( 'skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20151215', true );
		wp_enqueue_script( 'business-roy', get_template_directory_uri() . '/assets/js/theme.js', array('jquery'), true );
		
		/** Load Style */
		wp_enqueue_style( 'owl-carousel', get_template_directory_uri(). '/assets/css/owl.carousel.css');
		wp_enqueue_style( 'prettyPhoto', get_template_directory_uri() . '/assets/css/prettyPhoto.css' );
		wp_enqueue_style( 'aos-animation', get_template_directory_uri() . '/assets/css/aos.css', array(), true );
	
	}else{
		wp_enqueue_script( 'business-roy-compressjs', get_template_directory_uri() . '/assets/js/compress.min.js', array('jquery'), true );
		wp_enqueue_style( 'business-roy-compresscss', get_template_directory_uri() . '/assets/css/compress.min.css' );
	}

	wp_enqueue_style( 'business-roy-style', get_stylesheet_uri() );
	wp_enqueue_style( 'business-roy-responsive', get_template_directory_uri(). '/assets/css/responsive.css');

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'business_roy_scripts' );

/**
 * Sets the Business Roy Template Instead of front-page.
 */
function business_roy_front_page_set( $template ) {

  $business_roy_front_page = get_theme_mod( 'business_roy_enable_frontpage' ,'disable' );

  if( !in_array($business_roy_front_page, array('enable', '1')) ){

    if ( 'posts' == get_option( 'show_on_front' ) ) {

      include( get_home_template() );

    } else {

      include( get_page_template() );

    }
  }
}
add_filter( 'business_roy_enable_front_page', 'business_roy_front_page_set' );

/**
 * Load Files.
 */
require get_template_directory() . '/inc/init.php';


if(!function_exists('business_roy_dynamic_fonts')){
	function business_roy_dynamic_fonts($icon_set = array()){
		// Load Font-awesome CSS Library File
		wp_register_style( 'fontawesome4.5', get_template_directory_uri(). '/assets/library/fontawesome/css/all.min.css');
		wp_enqueue_style( 'fontawesome4.5');
	}
}


/**
 * Registers block patterns and categories.
 *
 * @since Business Roy 1.1.0
 *
 * @return void
 */
function business_roy_register_block_patterns() {

	$patterns = array();

	$block_pattern_categories = array(
		'businessroy' 			=> array( 'label' => __( 'Themes Patterns', 'business-roy' ) ),
		'businessroy-about' 	=> array( 'label' => __( 'Theme About Section', 'business-roy' ) ),
		'businessroy-fservice' 	=> array( 'label' => __( 'Theme Features Service Section', 'business-roy' ) ),
		'businessroy-call-to-action' 	=> array( 'label' => __( 'Theme Call To Action', 'business-roy' ) ),
		'businessroy-client-section' 	=> array( 'label' => __( 'Theme Client Section', 'business-roy' ) ),
		'businessroy-counter' 	=> array( 'label' => __( 'Theme Counter', 'business-roy' ) ),
		'businessroy-portfolio' 	=> array( 'label' => __( 'Theme Portfolio', 'business-roy' ) ),
		'businessroy-service' 	=> array( 'label' => __( 'Theme Service', 'business-roy' ) ),
		'businessroy-team' 	=> array( 'label' => __( 'Theme Team', 'business-roy' ) ),
		'businessroy-testimonial' 	=> array( 'label' => __( 'Theme Testimonial', 'business-roy' ) ),
		'businessroy-video-call-to-action' 	=> array( 'label' => __( 'Theme Video Call To Action', 'business-roy' ) ),
		'businessroy-service' 	=> array( 'label' => __( 'Theme Service', 'business-roy' ) ),
		'businessroy-how-it-works' 	=> array( 'label' => __( 'Theme How It Works', 'business-roy' ) ),
		'businessroy-contact' 	=> array( 'label' => __( 'Theme Contact', 'business-roy' ) ),
	);

	/**
	 * Filters the theme block pattern categories.
	 *
	 * @since Business Roy 1.1.0
	 *
	 * @param array[] $block_pattern_categories {
	 *     An associative array of block pattern categories, keyed by category name.
	 *
	 *     @type array[] $properties {
	 *         An array of block category properties.
	 *
	 *         @type string $label A human-readable label for the pattern category.
	 *     }
	 * }
	*/

	$block_pattern_categories = apply_filters( 'business_roy_register_block_patterns', $block_pattern_categories );

	foreach ( $block_pattern_categories as $name => $properties ) {

		if ( ! WP_Block_Pattern_Categories_Registry::get_instance()->is_registered( $name ) ) {

			register_block_pattern_category( $name, $properties );

		}
	}
}
add_action( 'init', 'business_roy_register_block_patterns', 9 );


if( !function_exists ('business_roy_nav_buttons')){
	/** 
	 * Adding Search and Sidebar Navigation Items
	*/
	function business_roy_nav_buttons() {

		$items = "<div class='nav-buttons'>";

		$enable_search = get_theme_mod('business_roy_enable_search', 'enable');
		
		if( $enable_search == 'enable'):
			$items .= '<span class="menu-item-search no-hover"><a class="searchicon" href="javascript:void(0)"><i class="fas fa-search"></i></a></span>';
		endif;

		if( get_theme_mod('business_roy_menu_sidebar', 'disable') == 'enable'){
			$items .= '<span class="menu-item-sidebar no-hover"><a class="" href="javascript:void(0)" data-toggle-target=".header-sidebar-content"  data-toggle-body-class="showing-menu-modal" aria-expanded="false" data-set-focus=".close-nav-toggle"><i class="fas fa-bars"></i></a></span>';
		}

		$business_roy_header_button_enable = get_theme_mod('business_roy_header_button_enable', 'enable');
		if( $business_roy_header_button_enable == 'enable' ){
			$items .= '<span class="menu-item-button no-hover">'. business_roy_header_button().'</span>';
		}

		$items .="</div>";

		echo $items;
	}
	add_action('business_roy_nav_buttons', 'business_roy_nav_buttons');
}