<?php
/**
 * Business Roy Theme Customizer
 *
 * @package Business Roy
 */
/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function business_roy_customize_register( $wp_customize ) {
	
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	$wp_customize->get_section( 'static_front_page' )->title 	= esc_html__('Enable Front Page', 'business-roy');
	$wp_customize->get_section( 'static_front_page' )->priority = 25;
	
	$wp_customize->get_control('header_textcolor')->section = "title_tagline";

	/**
	 * Upgrade Pro Version
	*/
	$wp_customize->add_setting('business_roy_title_tagline_upgrade_text', array(
		'sanitize_callback' => 'business_roy_sanitize_text'
	));

	$wp_customize->add_control(new BusinessRoy_Upgrade_Text($wp_customize, 'business_roy_title_tagline_upgrade_text', array(
		'section' => 'title_tagline',
		'label' => esc_html__('For More Settings,', 'business-roy'),
		'choices' => array(
			esc_html__('Title, Tagline & Logo Alignment', 'business-roy'),
			esc_html__('Adjust Title, Tagline & Logo', 'business-roy')
		),
		'priority' => 250
	)));	

	
	$wp_customize->register_control_type('BusinessRoy_Custom_Control_Tab');
	$wp_customize->register_control_type('BusinessRoy_Background_Control');
    $wp_customize->register_control_type('BusinessRoy_Range_Slider_Control');
    $wp_customize->register_control_type('BusinessRoy_Sortable_Control');
    $wp_customize->register_control_type('BusinessRoy_Color_Tab_Control');
    $wp_customize->register_control_type('BusinessRoy_Custom_Control_Buttonset');
	$wp_customize->register_section_type('BusinessRoy_Toggle_Section');
	$wp_customize->register_section_type('BusinessRoy_Upgrade_Section');

	/** 
	 * pro controller
	*/
    require get_template_directory() . '/inc/customizer/customizer-panel/social-settings.php';
    require get_template_directory() . '/inc/customizer/customizer-panel/quick-info.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/footer.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/colors.php';
	
	/**
	 *	Enable Front Page.
	*/
	$wp_customize->add_setting('business_roy_enable_frontpage', array(
        'default' => 'disable',
        'sanitize_callback' => 'business_roy_sanitize_switch',     //done
    ));
    $wp_customize->add_control(new BusinessRoy_Switch_Control($wp_customize, 'business_roy_enable_frontpage', array(
        'label' => esc_html__('Enable FrontPage', 'business-roy'),
        'settings' => 'business_roy_enable_frontpage',
		'description' => esc_html__( 'Note :- Overwrites  the home page display setting and shows the frontpage', 'business-roy' ),
        'section' => 'static_front_page',
        'switch_label' => array(
            'enable' => esc_html__('On', 'business-roy'),
            'disable' => esc_html__('Off', 'business-roy'),
        ),
    )));
    

    // List All Pages
	$pages = array();
	$pages_obj = get_pages();
	$pages[''] = esc_html__('Select Page', 'business-roy');
	foreach ($pages_obj as $page) {
	    $pages[$page->ID] = $page->post_title;
	}
	$blog_cat = business_roy_post_category();

	/**
	 * Header Settings.
	*/
	$wp_customize->add_panel('business_roy_header_settings', array(
		'title'		=>	esc_html__('Header Settings','business-roy'),
		'priority'	=>	10,
	));
	
	require get_template_directory() . '/inc/customizer/customizer-panel/general-settings.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/top-header.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/header.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/header-cta.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/blog.php';
	
	/**
	 * Home Page Settings
	*/
	$wp_customize->add_panel('business_roy_frontpage_settings', array(
		'title'		=>	esc_html__('Home Sections','business-roy'),
		'priority'	=>	35,
		'description' => esc_html__('Drag and Drop to Reorder', 'business-roy'). '<img class="business_roy_light-drag-spinner" src="'.admin_url('/images/spinner.gif').'">',
	));
	require get_template_directory() . '/inc/customizer/customizer-panel/home/common-settings.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/breadcrumb.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/slider.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/aboutus.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/promo-services.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/cta.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/services.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/video-cta.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/how_it_works.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/recentwork.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/testimonial.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/team.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/client.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/blog.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/contact-settings.php';
	require get_template_directory() . '/inc/customizer/customizer-panel/home/counter.php';

/**
 * Page Layout Sidebar Options
*/
$wp_customize->add_section('business_roy_sidebar', array(
	'title'		=>	esc_html__('Page Sidebar Settings','business-roy'),
	'panel'		=> 'business_roy_general_settings_panel',
));

	$wp_customize->add_setting("business_roy_page_heading", array(
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control(new BusinessRoy_Customize_Heading($wp_customize, "business_roy_page_heading", array(
        'section' => "business_roy_sidebar",
        'label' => esc_html__('Page Layout Setting', 'business-roy'),
    )));

	$wp_customize->add_setting('business_roy_page_sidebar', array(
		'default' => 'no',
		'sanitize_callback' => 'business_roy_sanitize_options'
	));
	$wp_customize->add_control(new BusinessRoy_Selector($wp_customize, 'business_roy_page_sidebar', array(
		'section' => 'business_roy_sidebar',
		//'label' => esc_html__('Page Layout', 'business-roy'),
		'options' => array(
			'left' => get_template_directory_uri() . '/inc/customizer/images/left-sidebar.png',
			'right' => get_template_directory_uri() . '/inc/customizer/images/right-sidebar.png',
			'no' => get_template_directory_uri() . '/inc/customizer/images/no-sidebar.png',
		)
	)));

	/**
	 * Upgrade Pro Version
	*/
	$wp_customize->add_setting('business_roy_pro_upgrade_page_layout_text', array(
		'sanitize_callback' => 'business_roy_sanitize_text'
	));

	$wp_customize->add_control(new BusinessRoy_Upgrade_Text($wp_customize, 'business_roy_pro_upgrade_page_layout_text', array(
		'section' => 'business_roy_sidebar',
		'label' => esc_html__('For More Settings,', 'business-roy'),
		'choices' => array(
			esc_html__('Sticky widget sidebar options', 'business-roy'),
		),
		'priority' => 250
	)));

	/****** Upgrade Pro in Front Page Section */
	$wp_customize->add_section(new BusinessRoy_Upgrade_Section($wp_customize, 'business_roy_frontpage_upgrade_pro_section', array(
		'title' => esc_html__('More Sections on Premium', 'business-roy'),
		'panel' => 'business_roy_frontpage_settings',
		'priority' => 1000,
		'options' => array(
			esc_html__('- Each section seats more styles and customization options', 'business-roy'),
			esc_html__('- Services Section with Multiple Layouts', 'business-roy'),
			esc_html__('- News and Events Update Section', 'business-roy'),
			esc_html__('- Free Hand Text (HTML)', 'business-roy'),
			esc_html__('- Highlight Section', 'business-roy'),
			esc_html__('- WooCommerce Section', 'business-roy'),
			esc_html__('- Pricing table with advance features', 'business-roy'),
			esc_html__('- Advanced Tab Section', 'business-roy'),
			esc_html__('- 40+ Custom Patterns', 'business-roy'),
			esc_html__('- Advanced Typography Settings', 'business-roy'),
			esc_html__('----------------------------------------------- Many More Sections ---------', 'business-roy'),
			esc_html__('Elementor page builder compatible. All the above sections can be created with Elementor page builder or customizer whichever you prefer.', 'business-roy'),
		)
	)));
		
}
add_action( 'customize_register', 'business_roy_customize_register' );

add_action( 'customize_controls_print_scripts', 'business_roy_customizer_dynamic_script', 30 );
function business_roy_customizer_dynamic_script(){
	?>
	<script type="text/javascript">
		jQuery( function( $ ) {
			wp.customize.panel( 'business_roy_frontpage_settings', function( section ) {
				section.expanded.bind( function( isExpanded ) {
					if ( isExpanded ) {
						wp.customize.previewer.previewUrl.set( '<?php echo esc_js( home_url('/') ); ?>' );
					}
				} );
			} );
		} );
	</script>
	<?php
}
/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function business_roy_customize_partial_blogname() {
	bloginfo( 'name' );
}
/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function business_roy_customize_partial_blogdescription() {
	bloginfo( 'description' );
}


/**
 * Enqueue Block Editor Script and styles.
*/
function business_roy_block_editor_assets() {

	wp_enqueue_script( "business-roy-block-admin", get_template_directory_uri() .'/assets/js/blockadmin.js', '', '', true);
    
}
add_action( 'admin_enqueue_scripts', 'business_roy_block_editor_assets', );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
*/
function business_roy_customize_preview_js() {
	wp_enqueue_script( 'business-roy-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'business_roy_customize_preview_js' );
/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 *
 * Enqueue required scripts/styles for customizer panel
 *
 * @since 1.0.0
 *
 */
function business_roy_customize_scripts(){

	wp_enqueue_style( 'fontawesome', get_template_directory_uri(). '/assets/library/fontawesome/css/all.min.css');
	
	wp_enqueue_style( 'choosen', get_template_directory_uri() . '/assets/library/chosen/chosen.min.css' );
	wp_enqueue_script( 'choosen', get_template_directory_uri() . '/assets/library/chosen/chosen.jquery.js', array('jquery'), true );

    wp_enqueue_style('business-roy-customizer', get_template_directory_uri() . '/assets/css/customizer.css');
    wp_enqueue_script('business-roy-customizer', get_template_directory_uri() . '/assets/js/customizer-admin.js', array('jquery', 'customize-controls'), true);
}
add_action('customize_controls_enqueue_scripts', 'business_roy_customize_scripts');

/**
 * Section Re Order
*/
add_action('wp_ajax_business_roy_sections_reorder', 'business_roy_sections_reorder');
function business_roy_sections_reorder() {
    if (isset($_POST['sections'])) {
        set_theme_mod('business_roy_frontpage_sections', $_POST['sections']);
    }
    wp_die();
}
function business_roy_get_section_position($key) {
    $sections = business_roy_homepage_section();
    $position = array_search($key, $sections);
    $return = ( $position + 1 ) * 11;
    return $return;
}
if( !function_exists('business_roy_homepage_section') ){
	function business_roy_homepage_section(){
		$defaults = apply_filters('business_roy_homepage_sections',
			array(
				'business_roy_aboutus_section',
				'business_roy_promoservice_section',
				'business_roy_calltoaction_section',
				'business_roy_service_section',
				'business_roy_video_calltoaction_section',
				'business_roy_how_it_works_section',
				'business_roy_recentwork_section',
				'business_roy_testimonial_section',
				'business_roy_counter_section',
				'business_roy_team_section',
				'business_roy_client_section',
				'business_roy_blog_section',
				'business_roy_contact_section',
			)
		);
		$sections = get_theme_mod('business_roy_frontpage_sections', $defaults);
        return $sections;
	}
}

// Upgrade Text
if ( class_exists( 'WP_Customize_Control' ) ) {
	if ( !class_exists( 'BusinessRoy_Upgrade_Text' ) ) {
		class BusinessRoy_Upgrade_Text extends WP_Customize_Control {

	        public $type = 'business-roy-upgrade-text';

	        public function render_content() {
	            ?>
	            <label>
	                <span class="dashicons dashicons-info"></span>

	                <?php if ($this->label) { ?>
	                    <span>
	                        <?php echo wp_kses_post($this->label); ?>
	                    </span>
	                <?php } ?>

	                <a href="<?php echo apply_filters('business-roy-pro-link', esc_url('https://ikreatethemes.com/wordpress-themes/business-roy/') );?>" target="_blank"> <strong><?php echo esc_html__('UPGRADE TO PRO', 'business-roy'); ?></strong></a>
	            </label>

	            <?php if ($this->description) { ?>
	                <span class="description customize-control-description">
	                    <?php echo wp_kses_post($this->description); ?>
	                </span>
	                <?php
	            }

	            $choices = $this->choices;
	            if ($choices) {
	                echo '<ul>';
	                foreach ($choices as $choice) {
	                    echo '<li>' . esc_html($choice) . '</li>';
	                }
	                echo '</ul>';
	            }
	        }

	    }
	}
}

if ( class_exists( 'WP_Customize_Section' ) ) {
	if ( !class_exists( 'BusinessRoy_Upgrade_Section' ) ) {
		class BusinessRoy_Upgrade_Section extends WP_Customize_Section {

	        /**
	         * The type of customize section being rendered.
	         *
	         * @since  1.0.0
	         * @access public
	         * @var    string
	         */
	        public $type = 'business-roy-upgrade-section';

	        /**
	         * Custom button text to output.
	         *
	         * @since  1.0.0
	         * @access public
	         * @var    string
	         */
	        public $text = '';
	        public $options = array();

	        /**
	         * Add custom parameters to pass to the JS via JSON.
	         *
	         * @since  1.0.0
	         * @access public
	         * @return void
	         */
	        public function json() {
	            $json = parent::json();

	            $json['text'] = $this->text;
	            $json['options'] = $this->options;

				// print_r($json); exit;
	            return $json;
	        }

	        /**
	         * Outputs the Underscore.js template.
	         *
	         * @since  1.0.0
	         * @access public
	         * @return void
	         */
	        protected function render_template() {
	            ?>
	            <li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }} cannot-expand">
	                <label>
	                    <# if ( data.title ) { #>
	                    {{ data.title }}
	                    <# } #>
	                </label>

	                <# if ( data.text ) { #>
	                {{ data.text }}
	                <# } #>

	                <# _.each( data.options, function(key, value) { #>
	                {{ key }}<br/>
	                <# }) #>

	                <a href="<?php echo apply_filters('business-roy-pro-link', esc_url('https://ikreatethemes.com/wordpress-themes/business-roy/') );?>" class="button button-primary" target="_blank"><?php echo esc_html__('Upgrade to Pro', 'business-roy'); ?></a>
	            </li>
	            <?php
	        }
	    }
	}
}

/**
 * Multiple Gallery Image Upload Custom Control Function
*/
if ( class_exists( 'WP_Customize_Control' ) ) :
	if( ! class_exists('BusinessRoy_Gallery_Control')):
		class BusinessRoy_Gallery_Control extends WP_Customize_Control{
			public $type = 'gallery';         
			public function render_content() { ?>
			<div>
				<span class="customize-control-title">
					<?php echo esc_html( $this->label ); ?>
				</span>

				<?php if($this->description){ ?>
					<span class="description customize-control-description">
					<?php echo wp_kses_post( $this->description ); ?>
					</span>
				<?php } ?>

				<div class="gallery-screenshot clearfix">
				<?php
					{
					$ids = explode( ',', $this->value() );
						foreach ( $ids as $attachment_id ) {
							$img = wp_get_attachment_image_src( $attachment_id, 'thumbnail' );
							if( is_array($img) && isset($img[0])){
								echo '<div class="screen-thumb"><img src="' . esc_url( $img[0] ) . '" /></div>';
							}
						}
					}
				?>
				</div>
				<input id="edit-gallery" class="button upload_gallery_button" type="button" value="<?php esc_attr_e('Add/Edit Gallery','business-roy') ?>" />
				<input id="clear-gallery" class="button upload_gallery_button" type="button" value="<?php esc_attr_e('Clear','business-roy') ?>" />
				<input type="hidden" data-name="gallery" class="gallery_values" <?php echo $this->link(); ?> value="<?php echo esc_attr( $this->value() ); ?>">
			</div>
			<?php }
		}
	endif;
endif;