<?php

function get_dynamic_padding_value($padding){
    $css = $tab_css = $mobile_css = '';
    // desktop padding
    $padding_desktop = business_roy_cssbox_values_inline( $padding, 'desktop' );
    if ( strpos( $padding_desktop, 'px' ) !== false ) {
        $css .= 'padding:' . $padding_desktop . ';';
    }
    // tablet padding
    $padding_desktop = business_roy_cssbox_values_inline( $padding, 'tablet' );
    if ( strpos( $padding_desktop, 'px' ) !== false ) {
        $tab_css .= 'padding:' . $padding_desktop . ';';
    }
    // mobile padding
    $padding_desktop = business_roy_cssbox_values_inline( $padding, 'mobile' );
    if ( strpos( $padding_desktop, 'px' ) !== false ) {
        $mobile_css .= 'padding:' . $padding_desktop . ';';
    }

    return ['desktop' => $css, 'tablet' => $tab_css, 'mobile' => $mobile_css];

}

function get_dynamic_margin_value($margin){
    $css = $tab_css = $mobile_css = '';
    // desktop margin
    $margin_desktop = business_roy_cssbox_values_inline( $margin, 'desktop' );
    if ( strpos( $margin_desktop, 'px' ) !== false ) {
        $css .= 'margin:' . $margin_desktop . ';';
    }
    // tablet margin
    $margin_desktop = business_roy_cssbox_values_inline( $margin, 'tablet' );
    if ( strpos( $margin_desktop, 'px' ) !== false ) {
        $tab_css .= 'margin:' . $margin_desktop . ';';
    }
    // mobile margin
    $margin_desktop = business_roy_cssbox_values_inline( $margin, 'mobile' );
    if ( strpos( $margin_desktop, 'px' ) !== false ) {
        $mobile_css .= 'margin:' . $margin_desktop . ';';
    }

    return ['desktop' => $css, 'tablet' => $tab_css, 'mobile' => $mobile_css];

}

function get_dynamic_radius_value($radius){
    $css = $tab_css = $mobile_css = '';

    $radius_desktop = business_roy_cssbox_values_inline( $radius, 'desktop' );
    if ( strpos( $radius_desktop, 'px' ) !== false ) {
        $css .= 'border-radius:' . $radius_desktop . ';';
    }
    // tablet radius
    $radius_desktop = business_roy_cssbox_values_inline( $radius, 'tablet' );
    if ( strpos( $radius_desktop, 'px' ) !== false ) {
        $tab_css .= 'border-radius:' . $radius_desktop . ';';
    }
    // mobile radius
    $radius_desktop = business_roy_cssbox_values_inline( $radius, 'mobile' );
    if ( strpos( $radius_desktop, 'px' ) !== false ) {
        $mobile_css .= 'border-radius:' . $radius_desktop . ';';
    }

    return ['desktop' => $css, 'tablet' => $tab_css, 'mobile' => $mobile_css];

}

function merge_two_arra($array1, $array2){

    $desktop = $array1['desktop'] . $array2['desktop'];
    $tablet  = $array1['tablet'] . $array2['tablet'];
    $mobile  = $array1['mobile'] . $array2['mobile'];

    return array(
        'desktop' => $desktop,
        'tablet' => $tablet,
        'mobile' => $mobile
    );

}

function get_dynamic_css_return_val( $wrapper, $desktop, $tablet, $mobile, $className){
    $dynamicCss = $tabletCss = $mobileCss = '';
    if( $wrapper && is_array($wrapper)){
            $dynamicCss = $wrapper['desktop'];
            $tabletCss = $wrapper['tablet'];
            $mobileCss = $wrapper['mobile'];
    }
    if( $desktop ){
        $dynamicCss .="{$className} {
            {$desktop}
        }";
    }
    if( $tablet ){
        $tabletCss .= "{$className} {
            {$tablet}
        }";
    }

    if($mobile ) {
        $mobileCss .= "{$className} {
            {$mobile}
        }";
    }


    // echo $dynamic_css; exit;
    return array(
        'desktop' => $dynamicCss,
        'tablet' => $tabletCss,
        'mobile' => $mobileCss
    );
    
}

function business_roy_dynamic_header_css(){

    $css = $tab_css = $mobile_css = "";
    
    // Padding
    $padding = get_theme_mod('business_roy_header_margin_padding');
    $margin_padding = json_decode( $padding, true );

    if( $margin_padding && is_array($margin_padding) ){
        $padding = get_dynamic_padding_value($margin_padding['padding']);
        $css.= $padding['desktop'];
        $tab_css.= $padding['tablet'];
        $mobile_css.= $padding['mobile'];

        // margin
        $margin = get_dynamic_margin_value($margin_padding['margin']);
        $css.= $margin['desktop'];
        $tab_css.= $margin['tablet'];
        $mobile_css.= $margin['mobile'];

        // margin
        $radius = get_dynamic_radius_value($margin_padding['radius']);
        $css.= $radius['desktop'];
        $tab_css.= $radius['tablet'];
        $mobile_css.= $radius['mobile'];
    }


    // bg type
    $bg_type = get_theme_mod("business_roy_header_bg_type", "color-bg");
    if( $bg_type == 'image-bg'){
        $bg_image = get_theme_mod('business_roy_header_background_image');
        $bg_color = get_theme_mod('business_roy_header_bg_color', '#f2f4f6');
        if ( $bg_image ) {
            $css .= ' 
                background-image: url("' . esc_url( $bg_image ) . '"); 
                background-repeat: '. get_theme_mod('business_roy_header_background_image_repeat', 'no-repeat').'; 
                background-position: '. get_theme_mod('business_roy_header_background_image_position', 'center center').'; 
                background-size: '. get_theme_mod('business_roy_header_background_image_size', 'cover').';
                background-color: '. $bg_color. ';
                background-attachment: '. get_theme_mod('business_roy_header_background_image_attach', 'fixed'). ';
            ';
            
        }
    }else if( $bg_type == 'color-bg'){
        $color = get_theme_mod("business_roy_header_bg_color");
        if( $color ){
            $css .= "background-color:" . $color . ";";
        }
    }else if( $bg_type == 'gradient-bg'){
        $color = get_theme_mod("business_roy_header_bg_gradient");
        $cg = array();
        if( $color ) {
            $cg[] = "$color";
            $css .= implode(';', $cg);
        }
        
    }

    return get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.nav-classic');    
}

function business_roy_dynamic_header_button_css(){

    $css = $tab_css = $mobile_css = "";
    
    // Padding
    $nav = get_theme_mod('business_roy_header_button_color');
    $nav = json_decode( $nav, true );
    if( isset($nav['padding'])){
        $padding = get_dynamic_padding_value($nav['padding']);
        $css.= $padding['desktop'];
        $tab_css.= $padding['tablet'];
        $mobile_css.= $padding['mobile'];
    }

    if( isset($nav['margin'])){
        // margin
        $margin = get_dynamic_margin_value($nav['margin']);
        $css.= $margin['desktop'];
        $tab_css.= $margin['tablet'];
        $mobile_css.= $margin['mobile'];
    }

    if( isset($nav['radius'])){
        // radius
        $radius = get_dynamic_radius_value($nav['radius']);
        $css.= $radius['desktop'];
        $tab_css.= $radius['tablet'];
        $mobile_css.= $radius['mobile'];
    }

    if( isset( $nav['background'] ) && $nav['background'] ){
        $css .="background-color: {$nav['background']};";
    }
    if( isset( $nav['text'] ) && $nav['text'] ){
        $css .="color: {$nav['text']};";
    }
    if( isset( $nav['font-size'] ) && $nav['font-size'] ){
        $css .="font-size: {$nav['font-size']}px;";
    }

    if( isset( $nav['width'] ) && $nav['width'] ){
        $css .="width: {$nav['width']}px;";
    }

    $css1= get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.business-roy-header-button');


    $css2 = array(
        'desktop' => '',
        'tablet' => '',
        'mobile' => '',
    );
    $nav = get_theme_mod('business_roy_header_button_hover_color');

    $nav = json_decode( $nav, true );
    if( ( isset( $nav['background'] ) && $nav['background'] ) || ( isset( $nav['text'] ) && $nav['text'] )  ){
        $css2['desktop'] = ".business-roy-header-button:hover{
            background-color: {$nav['background']};
            color: {$nav['text']};
        }";
    }
    
    return merge_two_arra($css1, $css2);

}

function business_roy_dynamic_header_nav_css(){

    $css = $css1 = $tab_css = $mobile_css = "";
    $nav = get_theme_mod('business_roy_header_item_group');
    $nav = json_decode( $nav, true );

    if( $nav && is_array($nav) ){
        $padding = get_dynamic_padding_value($nav['padding']);
        $css.= $padding['desktop'];
        $tab_css.= $padding['tablet'];
        $mobile_css.= $padding['mobile'];

        // margin
        $margin = get_dynamic_margin_value($nav['margin']);
        $css.= $margin['desktop'];
        $tab_css.= $margin['tablet'];
        $mobile_css.= $margin['mobile'];

        // Radius
        $radius = get_dynamic_radius_value($nav['radius']);
        $css.= $radius['desktop'];
        $tab_css.= $radius['tablet'];
        $mobile_css.= $radius['mobile'];
    

        if( $nav['bg_color']){
            $css.= "background-color:{$nav['bg_color']};";
        }
        if( $nav['color']){
            $css.= "color:{$nav['color']};";
        } 
    }
    
    $css1 = get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.box-header-nav .main-menu .page_item a, .box-header-nav .main-menu>.menu-item>a, .headertwo .box-header-nav .main-menu .page_item a, .headertwo .box-header-nav .main-menu>.menu-item>a');   
    
    $css2 = array(
        'desktop' => '',
        'tablet' => '',
        'mobile' => '',
    );
    $navwrap = get_theme_mod('business_roy_header_nav_wrap_bg_color');
    if( !empty( $navwrap ) ){
        $css2['desktop'] = ".nav-classic .nav-menu, .headertwo .nav-classic .nav-menu{background-color: {$navwrap};}";
    }

    return merge_two_arra($css1, $css2);
}

function business_roy_dynamic_header_nav_sub_menu_css(){

    // Bg Color, Color, Margin, Padding Radius 
    $css = $css1 = $css2 = $css3 = $tab_css = $mobile_css = "";

    $nav = get_theme_mod('business_roy_header_sub_item_group');
    $nav = json_decode( $nav, true );

    if( $nav && is_array($nav) ){
        $padding = get_dynamic_padding_value($nav['padding']);
        $css.= $padding['desktop'];
        $tab_css.= $padding['tablet'];
        $mobile_css.= $padding['mobile'];

        // margin
        $margin = get_dynamic_margin_value($nav['margin']);
        $css.= $margin['desktop'];
        $tab_css.= $margin['tablet'];
        $mobile_css.= $margin['mobile'];

        // Radius
        $radius = get_dynamic_radius_value($nav['radius']);
        $css.= $radius['desktop'];
        $tab_css.= $radius['tablet'];
        $mobile_css.= $radius['mobile'];
    
        if( $nav['color']){
            $css.= "color:{$nav['color']};";
        }   
    }

    $css1 = get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.box-header-nav .main-menu .children>.page_item>li, .box-header-nav .main-menu .sub-menu>li'); 

    if( $nav && is_array($nav) ){
        if( $nav['bg_color']){
            $css2 .= "background-color:{$nav['bg_color']};";
        }
    }
    $css3 = get_dynamic_css_return_val('', $css2, $tab_css, $mobile_css, '.box-header-nav .main-menu .children, .box-header-nav .main-menu .sub-menu'); 

    return merge_two_arra($css1, $css3);
}

function business_roy_dynamic_header_nav_active_menu_css(){

    // Bg Color, Color, Margin, Padding Radius 
    $css = $css1 = $tab_css = $mobile_css = "";

    $nav = get_theme_mod('business_roy_header_nav_hover_group');
    $nav = json_decode( $nav, true );

    if( $nav && is_array($nav) ){

        if( $nav['nav_bg_color']){
            $css.= "background-color:{$nav['nav_bg_color']};";
        }
        if( $nav['nav_color']){
            $css.= "color:{$nav['nav_color']};";
        }
        $css1 = get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.box-header-nav .main-menu .page_item.current_page_item>a, .box-header-nav .main-menu .page_item:hover>a, .box-header-nav .main-menu .page_item.focus>a, .box-header-nav .main-menu>.menu-item.current-menu-item>a, .box-header-nav .main-menu>.menu-item:hover>a, .box-header-nav .main-menu>.menu-item.focus>a, .box-header-nav .main-menu .children>.page_item:hover>a, .box-header-nav .main-menu .children>.page_item.focus>a, .box-header-nav .main-menu .sub-menu>.menu-item:hover>a, .box-header-nav .main-menu .sub-menu>.menu-item.focus>a, .headertwo .box-header-nav .main-menu .page_item.current_page_item>a, .headertwo .box-header-nav .main-menu>.menu-item.current-menu-item>a, .headertwo .box-header-nav .main-menu .page_item:hover>a, .headertwo .box-header-nav .main-menu .page_item.focus>a, .headertwo .box-header-nav .main-menu>.menu-item:hover>a, .headertwo .box-header-nav .main-menu>.menu-item.focus>a');    
    }

    return $css1;
}



function business_roy_dynamic_header_social_links_css(){

    $css = $tab_css = $mobile_css = "";
    $icon_color  = get_theme_mod('business_roy_social_icon_color');
    $icon_bg = get_theme_mod('business_roy_social_icon_bg_color');
    
    if( $icon_color ){
        $css .="color: {$icon_color};";
    }

    if( $icon_bg ){
        $css .="background-color: {$icon_bg}!important;";
    }
    
    $css1= get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.top-bar-menu ul.sp_socialicon li a i');
    

    $css = $tab_css = $mobile_css = "";

    $hover_color = get_theme_mod('business_roy_social_icon_hover_color');
    $hover_bg = get_theme_mod( 'business_roy_social_icon_hover_bg_color' );

    if( $hover_color ){
        $css .="color: {$hover_color};";
    }

    if( $hover_bg ){
        $css .="background-color: {$hover_bg};";
    }
    

    $css2= get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.top-bar-menu ul.sp_socialicon li:hover a i');
    
    return merge_two_arra($css1, $css2);

}


/**
 * Slider Section
 */
function business_roy_dynamic_slider_css(){

    $css = $tab_css = $mobile_css = "";

    $css1 = array(
        'desktop' => $css,
        'tablet' => $tab_css,
        'mobile' => $mobile_css
    );

    $css2 = get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.banner-slider .slider-item .slider-content');    

    $css1 = merge_two_arra($css1, $css2);

    /** font size */
    $css = $tab_css = $mobile_css = "";
    $font_size = get_theme_mod('business_roy_caption_title_font_size');

    if( $font_size ){
        $css.= ".banner-slider .slider-item .slider-content .maintitle{font-size: {$font_size}px}";
    }

    $css2 = array(
        'desktop' => $css,
        'tablet' => $tab_css,
        'mobile' => $mobile_css
    );

    $css1 = merge_two_arra($css1, $css2);


    /** slider height */
    $css = $tab_css = $mobile_css = "";
    $height = get_theme_mod('business_roy_slider_height');
    $tablet_height = get_theme_mod('business_roy_slider_height_tablet');
    $mobile_height = get_theme_mod('business_roy_slider_height_mobile');
    
    if( $height ){
        $css.= ".video-banner, .banner-slider .slider-item{height: {$height}vh}";
    }

    if( $tablet_height ){
        $tab_css.= ".video-banner, .banner-slider .slider-item{height: {$tablet_height}vh}";
    }

    if( $mobile_height ){
        $mobile_css.= ".video-banner, .banner-slider .slider-item{height: {$mobile_height}vh}";
    }

    $css2 = array(
        'desktop' => $css,
        'tablet' => $tab_css,
        'mobile' => $mobile_css
    );

    $css1 = merge_two_arra($css1, $css2);

    $css = $tab_css = $mobile_css = "";
    $overlay  = get_theme_mod('business_roy_banner_overlay_color');
    
    if($overlay){
        $css .=".banner-slider .slider-item:before{background: {$overlay};}";
    }

    $css2 = array(
        'desktop' => $css,
        'tablet' => $tab_css,
        'mobile' => $mobile_css
    );

    return merge_two_arra($css1, $css2);
}


function business_roy_dynamic_slider_seprator_css(){
    $css = $tab_css = $mobile_css = "";

    $slider_bottom_seperator = get_theme_mod("business_roy_slider_bottom_seperator", 'bottom');
    $slider_bottom_seperator_color = get_theme_mod("business_roy_slider_bs_color", '#e42032');
    $business_roy_slider_bs_height = get_theme_mod("business_roy_slider_bs_height", 60);
    $business_roy_slider_bs_height_tablet = get_theme_mod("business_roy_slider_bs_height_tablet","40");
    $business_roy_slider_bs_height_mobile = get_theme_mod("business_roy_slider_bs_height_mobile","20");

    if ($slider_bottom_seperator != 'none') {
        $css .= ".banner-slider .bottom-section-seperator svg{ fill: {$slider_bottom_seperator_color}; }";
        $css .= ".banner-slider .bottom-section-seperator{ height:{$business_roy_slider_bs_height}px; }";
        if (!empty($business_roy_slider_bs_height_tablet)) {
            $tab_css .= ".banner-slider .bottom-section-seperator{ height:{$business_roy_slider_bs_height_tablet}px; }";
        }
        if (!empty($business_roy_slider_bs_height_mobile)) {
            $mobile_css .= ".banner-slider .bottom-section-seperator{ height:{$business_roy_slider_bs_height_mobile}px; }";
        }
    }

    $css2 = array(
        'desktop' => $css,
        'tablet' => $tab_css,
        'mobile' => $mobile_css
    );
    
    return $css2;
    
}


/** promo service sction */
function business_roy_promoservice_dynamic_css(){
    $css = $tab_css = $mobile_css = "";

    $padding = get_theme_mod('business_roy_promoservice_icon_style');
    $val = json_decode( $padding, true );

    if( isset( $val['padding'] ) ){
        $padding = get_dynamic_padding_value($val['padding']);
        $css.= $padding['desktop'];
        $tab_css.= $padding['tablet'];
        $mobile_css.= $padding['mobile'];
    }

    if( isset( $val['color'] ) ){
        $css .= "color: {$val['color']};";
    }
    
    if( isset( $val['bordercolor'] ) ){
        $css .= "border-color: {$val['bordercolor']};";
    }
    if( isset( $val['borderwidth'] )){
        $css .= "border:solid {$val['borderwidth']}px {$val['bordercolor']};";
    }

    $css1 = get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.promoservice-wrap .feature-list .icon-box');    


    $css = $tab_css = $mobile_css = "";
    $padding = get_theme_mod('promoservice_grid');
    $val = json_decode( $padding, true );

    if( isset( $val['padding'] ) ){
        $padding = get_dynamic_padding_value($val['padding']);
        $css.= $padding['desktop'];
        $tab_css.= $padding['tablet'];
        $mobile_css.= $padding['mobile'];
    }

    if( isset( $val['radius'] ) ){
        $radius = get_dynamic_radius_value($val['radius']);
        $css.= $radius['desktop'];
        $tab_css.= $radius['tablet'];
        $mobile_css.= $radius['mobile'];
    }
    
    if( isset( $val['margin'] ) ){
        $margin = get_dynamic_margin_value($val['margin']);
        $css.= $margin['desktop'];
        $tab_css.= $margin['tablet'];
        $mobile_css.= $margin['mobile'];
    }

    $css2 = get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.promoservice-wrap .feature-list');    

    return merge_two_arra($css1, $css2);

}

/** counter section */
function business_roy_counter_dynamic_css(){
    $css = $tab_css = $mobile_css = "";

    $group = get_theme_mod('business_roy_counter_icon_style');
    $val = json_decode( $group, true );

    if( isset( $val['padding'] ) ){
        $padding = get_dynamic_padding_value($val['padding']);
        $css.= $padding['desktop'];
        $tab_css.= $padding['tablet'];
        $mobile_css.= $padding['mobile'];
    }

    if( isset( $val['radius'] ) ){
        $radius = get_dynamic_radius_value($val['radius']);
        $css.= $radius['desktop'];
        $tab_css.= $radius['tablet'];
        $mobile_css.= $radius['mobile'];
    }

    if( isset( $val['bg_color'] ) ){
        $css .= "background-color: {$val['bg_color']};";
    }
    
    if( isset( $val['color'] )){
        $css .= "color: {$val['color']};";
    }
    
    if( isset( $val['bordercolor'] ) && !empty($val['bordercolor'] )){
        $css .= "border-color: {$val['bordercolor']};";
    }

    if( isset( $val['borderwidth'] ) && !empty( $val['borderwidth'] )){
        $css .= "border: {$val['borderwidth']}px solid {$val['bordercolor']}";
    }
    
    $css1 = get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.counter-section .achivement-items ul li .timer-icon');
    
    $css = $tab_css = $mobile_css = "";

    $group = get_theme_mod('business_roy_counter_group_style');
    $val = json_decode( $group, true );
    
    if( isset( $val['padding'] ) ){
        $padding = get_dynamic_padding_value($val['padding']);
        $css.= $padding['desktop'];
        $tab_css.= $padding['tablet'];
        $mobile_css.= $padding['mobile'];
    }

    if( isset( $val['radius'] ) ){
        $radius = get_dynamic_radius_value($val['radius']);
        $css.= $radius['desktop'];
        $tab_css.= $radius['tablet'];
        $mobile_css.= $radius['mobile'];
    }

    if( isset( $val['bg_color'] ) ){
        $css .= "background-color: {$val['bg_color']};";
    }
    
    if( isset( $val['color'] )){
        $css .= "color: {$val['color']};";
    }

    if( isset( $val['bordercolor'] ) && !empty($val['bordercolor'] )){
        $css .= "border-color: {$val['bordercolor']};";
    }

    if( isset( $val['borderwidth'] ) && !empty( $val['borderwidth'] )){
        $css .= "border: {$val['borderwidth']}px solid {$val['bordercolor']}";
    }
    
    
    $css2 = get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.counter-section .achivement-items ul li');
    
    return merge_two_arra($css1, $css2);
    
    
}

/** Team Section Style */
function business_roy_team_dynamic_css(){
    $css = $tab_css = $mobile_css = "";

    $group = get_theme_mod('business_roy_team_image_style');
    $val = json_decode( $group, true );
    
    if( isset( $val['height'] ) && $val['height'] ){
        $css .= "height: {$val['height']}px;";
    }
    
    $css1 = get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.team-section .box figure img, .team-section.style2 .box figure img');
    
    $css = $tab_css = $mobile_css = "";

    $group = get_theme_mod('business_roy_team_grid_style');
    $val = json_decode( $group, true );

    if( isset( $val['radius'] ) ){
        $radius = get_dynamic_radius_value($val['radius']);
        $css.= $radius['desktop'];
        $tab_css.= $radius['tablet'];
        $mobile_css.= $radius['mobile'];
    }

    if( isset( $val['bg_color'] ) ){
        $css .= "background-color: {$val['bg_color']};";
    }
    
    $css2 = get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.team-section .box, .team-section.style2 .box');
    
    return merge_two_arra($css1, $css2);
    
    
}


/*********
 * Contact Section
 */
function business_roy_contact_dynamic_css(){
    $css = $tab_css = $mobile_css = "";

    $button_bg = get_theme_mod('business_roy_contact_social_button_bg_color');
    $button = get_theme_mod('business_roy_contact_social_button_text_color');
    $bg = get_theme_mod('business_roy_contact_info_bg_color');
    $css .= ".contact-detail{
        background: {$bg};
    }
    
    .contact-social-icon ul li a{
        background: {$button_bg};
        color: {$button};
    }
    
    ";
    
    $css1 = array(
        'desktop' => $css,
        'mobile' => '',
        'tablet' => ''
    );
    
    return $css1;
 
}

if( !function_exists('business_roy_dynamic_footer_css')){
    function business_roy_dynamic_footer_css(){
        $css = $tab_css = $mobile_css = "";

        $css = $css1 = array();
        $sectionname = "footer";
        $sectionclass = ".site-footer";
        $sectionbgtype = get_theme_mod('business_roy_footer_bg_type', 'color-bg');
        if ($sectionbgtype == 'color-bg' || $sectionbgtype == 'image-bg') {
            $sectionbgcolor = get_theme_mod('business_roy_' . $sectionname . '_bg_color');
            $css[] = "background-color: $sectionbgcolor";
        }
        if ($sectionbgtype == 'image-bg') {
            $sectionbgimage = get_theme_mod('business_roy_' . $sectionname . '_bg_image_url');
            if( $sectionbgimage ):
                $sectionbgimage_repeat = get_theme_mod('business_roy_' . $sectionname . '_bg_image_repeat', 'no-repeat');
                $sectionbgimage_size = get_theme_mod('business_roy_' . $sectionname . '_bg_image_size', 'cover');
                $sectionbgimage_position = get_theme_mod('business_roy_' . $sectionname . '_bg_position', 'center center');
                $sectionbgimage_position = str_replace('-', ' ', $sectionbgimage_position);
                $sectionbgimage_attach = get_theme_mod('business_roy_' . $sectionname . '_bg_image_attach', 'fixed');
                //$sectionbgoverlay = get_theme_mod('business_roy_' . $sectionname . '_overlay_color');

                $css[] = "background-image: url($sectionbgimage)";
                $css[] = "background-size: {$sectionbgimage_size}";
                $css[] = "background-position: {$sectionbgimage_position}";
                $css[] = "background-attachment: {$sectionbgimage_attach}";
                $css[] = "background-repeat: {$sectionbgimage_repeat}";
                // if (!empty($sectionbgoverlay)) {
                //     $css1[] = "background-color: $sectionbgoverlay";
                // }
            endif;
        } elseif ($sectionbgtype == 'video-bg') {
            // if (!empty($sectionbgoverlay)) {
            //     $css1[] = "background-color: $sectionbgoverlay";
            // }
        } elseif ($sectionbgtype == 'gradient-bg') {
            $sectiongradientcolor = get_theme_mod('business_roy_' . $sectionname . '_bg_gradient');
            $css[] = "$sectiongradientcolor";
        }

        $margin = get_theme_mod('business_roy_footer_margin');
        $margin = json_decode( $margin, true );
        $margin = get_dynamic_margin_value($margin);
        if( isset($margin['desktop'])){
            $css[] = $margin['desktop'];
        }

        $padding = get_theme_mod('business_roy_footer_padding');
        $padding = json_decode( $padding, true );
        $padding = get_dynamic_padding_value($padding);
        if( isset($padding['desktop'])){
            $css[] = $padding['desktop'];
        }

        // $tab_css.= $margin['tablet'];
        // $mobile_css.= $margin['mobile'];
        
        $css = "$sectionclass{" . implode(';', $css) . "}";
        $css .= "$sectionclass::before{" . implode(';', $css1) . "}";

        $foo = '';
        $top_seperator_color = get_theme_mod("business_roy_{$sectionname}_ts_color", '#112437');
        $top_seperator_height = get_theme_mod('business_roy_' . $sectionname . '_ts_height_desktop', 80);
        $top_seperator_height_tablet = get_theme_mod('business_roy_' . $sectionname . '_ts_height_tablet');
        $top_seperator_height_mobile = get_theme_mod('business_roy_' . $sectionname . '_ts_height_mobile');
        
        if( $top_seperator_color ){
            $css .= ".footer-seprator .section-seperator svg{fill: {$top_seperator_color}}";
        }
        if (!empty($top_seperator_height)) {
            $css .= ".footer-seprator .section-seperator.bottom-section-seperator{height: {$top_seperator_height}px}";
        }
        if (!empty($top_seperator_height_tablet)) {
            $tab_css .= ".footer-seprator .section-seperator.bottom-section-seperator{height: {$top_seperator_height_tablet}px}";
        }
        if (!empty($top_seperator_height_mobile)) {
            $mobile_css .= ".footer-seprator .section-seperator.bottom-section-seperator{height: {$top_seperator_height_mobile}px}";
        }
    
        $css1 = array(
            'desktop' => $css,
            'mobile' => $tab_css,
            'tablet' => $mobile_css
        );
        
        return $css1;
    }
}

if(!function_exists('business_roy_dynamic_breadcrub_css')){
    function business_roy_dynamic_breadcrub_css(){
     
        $css = $tab_css = $mobile_css = "";

        $margin = get_theme_mod('business_roy_titlebar_content_margin');
        $margin = json_decode( $margin, true );
        
        if( isset( $margin ) ){
            $margin = get_dynamic_margin_value($margin);
            $css.= $margin['desktop'];
            $tab_css.= $margin['tablet'];
            $mobile_css.= $margin['mobile'];
        }

        $sectionbgtype = get_theme_mod('business_roy_titlebar_bg_type', 'color-bg');
        $sectionbgcolor = get_theme_mod('business_roy_titlebar_bg_color');
        $sectionbgoverlay = '';
        
        $css1 = array();
        if ($sectionbgtype == 'color-bg') {
            $css .= "background-color: $sectionbgcolor;";
        } else if($sectionbgtype == 'none') {
            $css .= "background-color: transparent;";
        }
        
        // overlay
        $overlay = ".breadcrumb-section::before{" . implode(';', $css1) . "}";
        $css2 = array(
            'desktop' =>  $overlay,
            'mobile' => '',
            'tablet' => ''
        );
        
        $css1 = get_dynamic_css_return_val('', $css, $tab_css, $mobile_css, '.breadcrumb-section');
        
        return merge_two_arra($css2, $css1);
        
    }
}