<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Business Roy
 */
/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function business_roy_body_classes($classes){
    // Adds a class of hfeed to non-singular pages.
    if (!is_singular()) {
        $classes[] = 'hfeed';
    }
    // Adds a class of no-sidebar when there is no sidebar present.
    if (!is_active_sidebar('sidebar-1')) {
        $classes[] = 'no';
    }
    //Web Page Layout
    if (get_theme_mod('business_roy_site_layout', 'full_width') == 'boxed') {
        $classes[] = 'boxed';
    }
    return $classes;
}
add_filter('body_class', 'business_roy_body_classes');

if ( ! function_exists( 'wp_body_open' ) ) {
    /**
     * Body open hook.
     */
    function wp_body_open() {
        do_action( 'wp_body_open' );
    }
}
/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function business_roy_pingback_header(){
    if (is_singular() && pings_open()) {
        printf('<link rel="pingback" href="%s">', esc_url(get_bloginfo('pingback_url')));
    }
}
add_action('wp_head', 'business_roy_pingback_header');
/**
 *  Add Metabox.
*/
if( !function_exists( 'business_roy_page_layout_metabox' ) ):
    function business_roy_page_layout_metabox() {
        add_meta_box('business_roy_display_layout', 
            esc_html__( 'Display Page Layout Options', 'business-roy' ), 
            'business_roy_display_layout_callback', 
            array('page','post'), 
            'normal', 
            'high'
        );
    }
endif;
add_action('add_meta_boxes', 'business_roy_page_layout_metabox');
/**
 * Page and Post Page Display Layout Metabox function
*/
$business_roy_page_layouts =array(
    'leftsidebar' => array(
        'value'     => 'left',
        'label'     => esc_html__( 'Left Sidebar', 'business-roy' ),
        'thumbnail' => get_template_directory_uri() . '/inc/customizer/images/left-sidebar.png',
    ),
    'rightsidebar' => array(
        'value'     => 'right',
        'label'     => esc_html__( 'Right (Default)', 'business-roy' ),
        'thumbnail' => get_template_directory_uri() . '/inc/customizer/images/right-sidebar.png',
    ),
     'nosidebar' => array(
        'value'     => 'no',
        'label'     => esc_html__( 'Full width', 'business-roy' ),
        'thumbnail' => get_template_directory_uri() . '/inc/customizer/images/no-sidebar.png',
    )
);
/**
 * Function for Page layout meta box
*/
if ( ! function_exists( 'business_roy_display_layout_callback' ) ) {
    function business_roy_display_layout_callback(){
        global $post, $business_roy_page_layouts;
        wp_nonce_field( basename( __FILE__ ), 'business_roy_settings_nonce' ); ?>
        <table>
            <tr>
              <td>            
                <?php
                  $i = 0;  
                  foreach ($business_roy_page_layouts as $field) {  
                  $business_roy_page_metalayouts = esc_attr( get_post_meta( $post->ID, 'business_roy_page_layouts', true ) ); 
                ?>            
                  <div class="radio-image-wrapper slidercat" id="slider-<?php echo intval( $i ); ?>" style="float: right; margin-right: 25px;">
                    <label class="description">
                        <img src="<?php echo esc_url( $field['thumbnail'] ); ?>" style="max-width: 200px;" /></br>
                        <input type="radio" name="business_roy_page_layouts" value="<?php echo esc_attr( $field['value'] ); ?>" <?php checked( esc_html( $field['value'] ), 
                            $business_roy_page_metalayouts ); if(empty($business_roy_page_metalayouts) && esc_html( $field['value'] ) =='no'){ echo "checked='checked'";  } ?>/>
                         <?php echo esc_html( $field['label'] ); ?>
                    </label>
                  </div>
                <?php  $i++; }  ?>
              </td>
            </tr>            
        </table>
    <?php
    }
}
/**
 * Save the custom metabox data
*/
if ( ! function_exists( 'business_roy_save_page_settings' ) ) {
    function business_roy_save_page_settings( $post_id ) { 
        global $business_roy_page_layouts, $post;
         if ( !isset( $_POST[ 'business_roy_settings_nonce' ] ) || !wp_verify_nonce( sanitize_key( $_POST[ 'business_roy_settings_nonce' ] ) , basename( __FILE__ ) ) ) 
            return;
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE)  
            return;        
        if (isset( $_POST['post_type'] ) && 'page' == $_POST['post_type']) {  
            if (!current_user_can( 'edit_page', $post_id ) )  
                return $post_id;  
        } elseif (!current_user_can( 'edit_post', $post_id ) ) {  
                return $post_id;  
        }  
        foreach ($business_roy_page_layouts as $field) {  
            $old = esc_attr( get_post_meta( $post_id, 'business_roy_page_layouts', true) );
            if ( isset( $_POST['business_roy_page_layouts']) ) { 
                $new = sanitize_text_field( wp_unslash( $_POST['business_roy_page_layouts'] ) );
            }
            if ($new && $new != $old) {  
                update_post_meta($post_id, 'business_roy_page_layouts', $new);  
            } elseif ('' == $new && $old) {  
                delete_post_meta($post_id,'business_roy_page_layouts', $old);  
            } 
         } 
    }
}
add_action('save_post', 'business_roy_save_page_settings');

/**
 * Fully Translation ready Multilingual Compatible with Polylang and WPML plugins.
*/
if( function_exists( 'pll_register_string' ) ){
    /**
     * About Us 
    */
    pll_register_string( 'aboutus_readmore_btn', get_theme_mod('business_roy_aboutus_button_text'), 'business-roy', true );
    /**
     * Portfolio Services Section
    */
    pll_register_string( 'recentwork_title', get_theme_mod('business_roy_recentwork_title'), 'business-roy', true );
    pll_register_string( 'recentwork_subtitle', get_theme_mod('business_roy_recentwork_subtitle'), 'business-roy', true );
    /**
     * Video Call To Action Section
    */
    pll_register_string( 'video_calltoaction_title', get_theme_mod('business_roy_video_calltoaction_title'), 'business-roy', true );
    pll_register_string( 'video_calltoaction_subtitle', get_theme_mod('business_roy_video_calltoaction_subtitle'), 'business-roy', true );
    /** 
     * Our Services Section
    */
    pll_register_string( 'service_title', get_theme_mod('business_roy_service_title'), 'business-roy', true );
    pll_register_string( 'service_subtitle', get_theme_mod('business_roy_service_sub_title'), 'business-roy', true );
    pll_register_string( 'service_read_more', get_theme_mod('business_roy_service_button'), 'business-roy', true );
    /**
     * Call To Action Section
    */
    pll_register_string( 'calltoaction_title', get_theme_mod('business_roy_calltoaction_title'), 'business-roy', true );
    pll_register_string( 'calltoaction_subtitle', get_theme_mod('business_roy_calltoaction_subtitle'), 'business-roy', true );
    pll_register_string( 'calltoaction_button', get_theme_mod('business_roy_calltoaction_button'), 'business-roy', true );
    pll_register_string( 'calltoaction_button_one', get_theme_mod('business_roy_calltoaction_button_one'), 'business-roy', true );
    /**
     * Counter Services Section
    */
    pll_register_string( 'counter_title', get_theme_mod('business_roy_counter_title'), 'business-roy', true );
    pll_register_string( 'counter_subtitle', get_theme_mod('business_roy_counter_subtitle'), 'business-roy', true );
    /**
     * Blog Services Section
    */
    pll_register_string( 'blog_title', get_theme_mod('business_roy_blog_title'), 'business-roy', true );
    pll_register_string( 'blog_subtitle', get_theme_mod('business_roy_blog_subtitle'), 'business-roy', true );
    pll_register_string( 'blog_readmore_btn', get_theme_mod('business_roy_blogtemplate_btn'), 'business-roy', true );
    /**
     * Testimonial Services Section
    */
    pll_register_string( 'testimonial_title', get_theme_mod('business_roy_testimonial_title'), 'business-roy', true );
    pll_register_string( 'testimonial_subtitle', get_theme_mod('business_roy_testimonial_sub_title'), 'business-roy', true );
    /**
     * Team Services Section
    */
    pll_register_string( 'team_title', get_theme_mod('business_roy_team_title'), 'business-roy', true );
    pll_register_string( 'team_subtitle', get_theme_mod('business_roy_team_subtitle'), 'business-roy', true );
    /**
     * Client Logo Section
    */
    pll_register_string( 'client_title', get_theme_mod('business_roy_client_title'), 'business-roy', true );
    pll_register_string( 'client_subtitle', get_theme_mod('business_roy_client_sub_title'), 'business-roy', true );
}

function business_roy_header_button(){
    
    $business_roy_header_button_enable = get_theme_mod('business_roy_header_button_enable', 'enable');
    $business_roy_hb_title = get_theme_mod('business_roy_hb_title',esc_html__('Call Anytime 24/7', 'business-roy'));
    $business_roy_hb_text  = get_theme_mod('business_roy_hb_text',esc_html__('+01-559-236-8009', 'business-roy'));
    $business_roy_hb_icon  = get_theme_mod('business_roy_hb_icon', 'fa fa-phone-volume');
    $business_roy_hb_link  = get_theme_mod('business_roy_hb_link', esc_html__('tel:5592368009', 'business-roy'));
    $business_roy_hb_disable_mobile = get_theme_mod('business_roy_header_button_disable_mobile', true);
    $button_class = $business_roy_hb_disable_mobile ? ' mobile-button-hide' : '';
    
    if( $business_roy_header_button_enable == 'enable' ){ 
        ob_start();
        ?>
        <div class="quickcontact">
            <div class="get-tuch business-roy-header-button<?php echo $button_class; ?>">
                <?php if( $business_roy_hb_link): ?>
                    <a href="<?php echo esc_url( $business_roy_hb_link ); ?>">
                <?php endif; ?>
                    
                    <?php if( $business_roy_hb_icon ): ?>
                        <i class="<?php echo esc_attr($business_roy_hb_icon); ?>"></i>
                    <?php endif; ?>
                
                    <div class="quickcontactwrap buttonwrap">
                        <?php if( $business_roy_hb_title): ?>
                            <div class="quickcontact-title">
                                <?php echo esc_html( $business_roy_hb_title ); ?>
                            </div>
                        <?php endif; ?>
                        <?php if( $business_roy_hb_text): ?>
                            <span>
                                <?php echo esc_html( $business_roy_hb_text ); ?>
                            </span>
                        <?php endif; ?>
                    </div>
                <?php if( $business_roy_hb_link): ?>
                    </a>
                <?php endif; ?>
            </div>
        </div>
        <?php

        return ob_get_clean();




        return '<a class="btn btn-primary business-roy-header-button'.$button_class.'" href="'.esc_attr($business_roy_hb_link).'">'.wp_kses_post($business_roy_hb_text).'</a>';
    }
}
add_action('business_roy_header_button', 'business_roy_header_button');


if(!function_exists('business_roy_single_featured_image')){
    function business_roy_single_featured_image(){
        business_roy_post_format_media( get_post_format() );
    }
}

if(!function_exists('business_roy_single_post_meta')){
    function business_roy_single_post_meta(){
         do_action( 'business_roy_post_meta', 10 );
    }
}


if(!function_exists('business_roy_single_content')){
    function business_roy_single_content(){
        echo '<div class="articlewrap">';
            the_content( sprintf(
                wp_kses(
                    /* translators: %s: Name of current post. Only visible to screen readers */
                    __( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'business-roy' ),
                    array(
                        'span' => array(
                            'class' => array(),
                        ),
                    )
                ),
                get_the_title()
            ) );
        echo '</div>';
    }
}

if(!function_exists('business_roy_single_title')){
    function business_roy_single_title(){
        the_title( '<h3 class="title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h3>' ); 
    }
}


if(!function_exists('business_roy_single_author_box')){

    function business_roy_single_author_box(){ 
    
        global $post;  
        $author_id = get_post_field('post_author' , $post->ID); 
        $author_name = get_the_author_meta( 'display_name', $author_id );
        $author_desc = get_the_author_meta('description', $author_id);
        $author_url = get_author_posts_url( $author_id );
        $output = get_avatar_url($author_id);
    ?>
        <div class="author-box">
            <div class="author-avatar">
                <a href="<?php echo esc_url( $author_url ); ?>"><img src="<?php echo esc_url( $output ); ?>" alt="<?php echo esc_html( $author_name ); ?>"></a>
            </div>
            <div class="author-content">
                <h5><a href="<?php echo esc_url( $author_url ); ?>" class="author-name"><?php echo esc_html( $author_name ); ?></a></h5>
                <p><?php echo esc_html( $author_desc ); ?></p>
            </div>
        </div>
        <?php
    }
}

if(!function_exists('business_roy_single_pagination')){
    function business_roy_single_pagination(){
        ?>
        <div class="prevNextArticle d-flex box-content">
            <div class="prevnext-item previus">
                <?php
                    $next_post = get_next_post();
                    $prev = get_previous_post();
                    if( $prev ): 
                ?>
                    <a href="<?php echo esc_url( get_the_permalink( $prev->ID ) ); ?>" title="<?php echo esc_attr($prev->post_title); ?>" class="single-navigation previous-post" style="display: inline;">
                        <?php echo get_the_post_thumbnail( $prev->ID, 'thumbnail'); ?>
                    </a>
                <?php endif; ?>
                <?php previous_post_link( '%link', '<h5><span>'.esc_html__('Previous article','business-roy').'</span></h5><div class="title prev">%title</div>' ); ?>
            </div>
            <div class="prevnext-item text-right">
                <?php next_post_link( '%link', '<h5><span>'.esc_html__('Next article','business-roy').'</span></h5><div class="title next">%title</div>' ); ?>
                <?php if( $next_post ): ?>
                    <a href="<?php echo esc_url( get_the_permalink( $next_post->ID ) ); ?>" title="<?php echo esc_attr($next_post->post_title); ?>" class="single-navigation previous-post" style="display: inline;">
                        <?php echo get_the_post_thumbnail( $next_post->ID, 'thumbnail'); ?>
                    </a>
                <?php endif; ?>
            </div>
        </div>
        <?php
    }
}

if(!function_exists('business_roy_single_comment')){
    function business_roy_single_comment(){
       // If comments are open or we have at least one comment, load up the comment template.
       if ( comments_open() || get_comments_number() ) :
            comments_template();
        endif;
    }
}

if(!function_exists('business_roy_single_related_posts')){
    
    function business_roy_single_related_posts(){
        global $post;
        $related = get_posts( array( 'numberposts' => 4, 'post__not_in' => array($post->ID) ) );
        if(!empty($related ) ){
        ?>
        <div class="related posts">
            <h3 class="related-title"><?php echo esc_html__('Related Posts','business-roy') ?></h3>
            <div class="articlesListing d-grid d-grid-column-2">
            <?php
                foreach( $related as $post ) {
                    setup_postdata($post); 
                    
                        get_template_part( 'template-parts/content', 'related');

                    } 
                wp_reset_postdata(); 
            ?>
            </div>
        </div>
        <?php 
        }
    }
}
