<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Business Roy
 */
if ( ! function_exists( 'business_roy_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function business_roy_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}
		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);
		$posted_on = sprintf(
			/* translators: %s: post date. */
			//esc_html_x( 'On %s', 'post date', 'business-roy' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);
		echo '<span class="posted-on"> - On ' . $time_string . '</span>'; // WPCS: XSS OK.
	}
endif;

if ( ! function_exists( 'business_roy_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function business_roy_posted_by() {
		// $byline = sprintf(
		// 	/* translators: %s: post author. */
		// 	//esc_html_x( 'by %s', 'post author', 'business-roy' ),
		// 	'<span class="author vcard"><a class="url" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '"><i class="fas fa-user-circle"></i> ' . esc_html( get_the_author() ) . '</a></span>'
		// );
		// echo '<div><span class="byline"> ' . $byline . '</span></div>'; // WPCS: XSS OK.
		$byline = sprintf(
			/* translators: %s: post author. */
			//esc_html_x( 'by %s', 'post author', 'business-roy' ),
			'<span itemprop="author" itemtype="https://schema.org/Person" class="author vcard">' . get_avatar( get_the_author_meta( 'ID' ) , 30 ) . '<a itemprop="url" class="url" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);
		echo '<span itemprop="name" class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.
	}
endif;

if ( ! function_exists( 'business_roy_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function business_roy_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'business-roy' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'business-roy' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			}
			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'business-roy' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'business-roy' ) . '</span>', $tags_list ); // WPCS: XSS OK.
			}
		}
		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'business-roy' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}
		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'business-roy' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

if ( ! function_exists( 'business_roy_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function business_roy_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}
		if ( is_singular() ) :
			?>
			<div class="post-thumbnail">
				<?php the_post_thumbnail(); ?>
			</div><!-- .post-thumbnail -->
		<?php else : ?>
			<div class="blog-post-thumbnail">
				<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
					<?php
						the_post_thumbnail( 'post-thumbnail' );
					?>
				</a>
			</div>
		<?php
		endif; // End is_singular().
	}
endif;

if ( ! function_exists( 'business_roy_comments' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function business_roy_comments() {
		echo '<span class="comments-link"><span class="fa fa-comments"></span> ';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'no comment<span class="screen-reader-text"> on %s</span>', 'business-roy' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
		echo '</span>'; // WPCS: XSS OK.
	}
endif;

/**
 * Category Lists.
 */
if ( ! function_exists( 'business_roy_category' ) ) :
	function business_roy_category() {
	/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'business-roy' ) );
		if ( $categories_list ) {
			/* translators: 1: list of categories. */
			printf( '<span class="cat-links">' . '%1$s' . '</span>', $categories_list ); // WPCS: XSS OK.
		}
	}
endif;

/**
 * Filter the except length to 20 words.
 *
 * @param int $length Excerpt length.
 * @return int (Maybe) modified excerpt length.
 */
function business_roy_post_excerpt_length( $length ) {

	$excerpt_length = get_theme_mod( 'business_roy_post_excerpt_length', 20 );

	if( is_admin() ){

		return $length;

	}elseif( is_front_page() && !is_home() ){

		return 28;

	}else{

		return $excerpt_length;
	}
}
add_filter( 'excerpt_length', 'business_roy_post_excerpt_length', 999 );

/**
 * Filter the excerpt "read more" string.
 *
 * @param string $text "Read more" excerpt string.
 * @return string (Maybe) modified "read more" excerpt string.
 */
function business_roy_excerpt_more($text){
	
    if(is_admin()){

        return $text;
    }
    return '&hellip;';
}
add_filter( 'excerpt_more', 'business_roy_excerpt_more' );

if( !function_exists('business_roy_estimated_reading_time')){

    function business_roy_estimated_reading_time() {
        global $post;
        // get the content
        $the_content = $post->post_content;
        // count the number of words
        $words = str_word_count( strip_tags( $the_content ) );
        // rounding off and deviding per 200 words per minute
        $minute = floor( $words / 200 );
        // rounding off to get the seconds
        $second = floor( $words % 200 / ( 200 / 60 ) );
        // calculate the amount of time needed to read
        $estimate = $minute . ' min' . ( $minute == 1 ? '' : 's' ) . ', ' . $second . ' ' . ( $second == 1 ? '' : 's' );
        // create output
        $output = '<span> <i class="far fa-clock"></i> ' . $estimate . '</span>';
        // return the estimate
        return $output;
    }
}