<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 */
if ( ! function_exists( 'business_roy_section_title' ) ){
    /**
     * Section Main Title
     *
     * @since 1.0.0
     */
    function business_roy_section_title($super_title, $title, $titlestyle=null ) { 
        if( !empty( $super_title ) || !empty( $title ) ){ ?>
            <div class="section-title-wrapper <?php echo esc_attr($titlestyle); ?>" data-aos="fade-up" data-aos-duration="1500" data-aos-delay="100">
                <?php if( !empty( $super_title ) ){ ?>
                    <span class="super-title"><?php echo esc_html( $super_title ); ?></span>
                <?php } if( !empty( $title ) ){ ?>
                    <h2 class="section-title"><?php echo esc_html( $title ); ?></h2>
                <?php } ?>
            </div>
        <?php }
    }
}

if ( ! function_exists( 'business_roy_post_meta' ) ){
    /**
     * Post Meta Function
     *
     * @since 1.0.0
     */
    function business_roy_post_meta() { 
        $postdate    = get_theme_mod( 'business_roy_post_date_options', 'enable' );
        $postcomment = get_theme_mod( 'business_roy_post_comments_options', 'enable' );
        $postauthor  = get_theme_mod( 'business_roy_post_author_options', 'enable' );
        $read_time  = get_theme_mod( 'business_roy_post_reading_time', 'enable' );
        if( $postdate == 'enable' || $postcomment == 'enable' || $postauthor == 'enable' || $read_time == 'enable'):
      ?>
        <div class="entry-meta info">
            <?php
                if( !empty( $postauthor ) && $postauthor == 'enable' ) { business_roy_posted_by(); }
                if( !empty( $postdate ) && $postdate == 'enable' ) { business_roy_posted_on(); }
                if( !empty( $postcomment ) && $postcomment == 'enable' ) { business_roy_comments(); }
                if( !empty( $read_time ) && $read_time == 'enable' ) { echo business_roy_estimated_reading_time(); }
            ?>
        </div><!-- .entry-meta -->
       <?php
       endif;
    }
}
add_action( 'business_roy_post_meta', 'business_roy_post_meta' , 10 );

if( ! function_exists( 'business_roy_post_format_media' ) ) :
    /**
     * Posts format declaration function.
     *
     * @since 1.0.0
     */
    function business_roy_post_format_media( $postformat ) {
        if( is_singular( ) ){
          $imagesize = 'post-thumbnail';
        }else{
            $imagesize = '';
        }
        if( $postformat == "gallery" ) {
            $gallery                = get_post_gallery( get_the_ID(), false );
            $gallery_attachment_ids = explode( ',', $gallery['ids'] );
            if( is_array( $gallery ) ){ ?>
                <div class="postgallery-carousel cS-hidden">
                    <?php foreach ( $gallery_attachment_ids as $gallery_attachment_id ) { ?>
                        <div class="list">
                            <?php echo wp_get_attachment_image( $gallery_attachment_id, $imagesize ); // WPCS xss ok. ?>
                        </div>
                    <?php } ?>
                </div>
            <?php }else{  ?>
                <div class="blog-post-thumbnail">
                    <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
                        <?php
                          the_post_thumbnail( $imagesize );
                        ?>
                    </a>
                </div>
        <?php } }else if( $postformat == "video" ){
            $get_content  = apply_filters( 'the_content', get_the_content() );
            $get_video    = get_media_embedded_in_content( $get_content, array( 'video', 'object', 'embed', 'iframe' ) );
            if( !empty( $get_video ) ){ ?>
                <div class="video">
                    <?php echo $get_video[0]; // WPCS xss ok. ?>
                </div>
        <?php }else{ ?>
                <div class="blog-post-thumbnail">
                    <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
                        <?php
                          the_post_thumbnail( $imagesize );
                        ?>
                    </a>
                </div>
        <?php  } }else if( $postformat == "audio" ){
            $get_content  = apply_filters( 'the_content', get_the_content() );
            $get_audio    = get_media_embedded_in_content( $get_content, array( 'audio', 'iframe' ) );
            if( !empty( $get_audio ) ){ ?>
                <div class="audio">
                    <?php echo $get_audio[0]; // WPCS xss ok. ?>
                </div>
        <?php }else{  ?>
                <div class="blog-post-thumbnail">
                    <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
                        <?php
                          the_post_thumbnail( $imagesize );
                        ?>
                    </a>
                </div>
        <?php } }else if( $postformat == "quote" ) { 
                    
            $blocks = parse_blocks( get_the_content() );
	
            foreach ( $blocks as $block ) {
                if ( 'core/quote' === $block['blockName'] ) {
                    
                    echo apply_filters( 'the_content', render_block( $block ) );
                    
                    break;
                    
                }
                
            }
            
            ?>
                
        <?php }else{ ?>
                <div class="blog-post-thumbnail">
                    <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
                        <?php
                          the_post_thumbnail( $imagesize );
                        ?>
                    </a>
                </div>
        <?php }
    }
endif;

if ( ! function_exists( 'business_roy_footer_copyright' ) ){
    /**
     * Footer Copyright Information
     *
     * @since 1.0.0
     */
    function business_roy_footer_copyright() {
        
        echo esc_html( apply_filters( 'business_roy_footer_copyright', $content = esc_html__('&copy; Copyright ','business-roy') . date( 'Y' ) . ' ' . get_bloginfo( 'name' ) .'. ' ) );
        
        printf( 'All Rights Reserved. Developed by %1$s Powered by %2$s','<a href=" ' . esc_url('https://ikreatethemes.com/') . ' " rel="designer" target="_blank">'.esc_html__('Ikreate Themes','business-roy').'</a>', '<a href=" ' . esc_url('https://wordpress.org/') . ' " rel="designer" target="_blank">'.esc_html__('WordPress','business-roy').'</a>' );
        
    }
}
add_action( 'business_roy_copyright', 'business_roy_footer_copyright', 5 );

if (! function_exists( 'business_roy_quick_contact' ) ):
	function business_roy_quick_contact(){ ?>
		<ul class="sp_quick_info">
        	<?php
                $quick_content = get_theme_mod('business_roy_quick_content', json_encode(array(
                    array(
                        'icon' => 'fas fa-phone-volume',
                        'label' => esc_html('Call Anytime 24/7','business-roy'),
                        'val' => '+01-559-236-8009',
                        'link' => '',
                        'enable' => 'on'
                    ),
                    array(
                        'icon' => 'fas fa-map-marker-alt',
                        'label' => esc_html('Office Address','business-roy'),
                        'val' => '28 Street, New York City, USA',
                        'link' => '',
                        'enable' => 'on'
                    ),
                    array(
                        'icon' => 'far fa-envelope',
                        'label' => esc_html('Mail Us For Support','business-roy'),
                        'val' => 'info@ikreatethemes.com',
                        'link' => '',
                        'enable' => 'on'
                    )
                )));
                $quick_content = json_decode( $quick_content );
                if( is_array( $quick_content ) ){
                    foreach( $quick_content as $quick ){
                       // if( $quick->enable !== 'on') continue;
                        ?>
                             <li class="sp_quick_info">
                                <?php if( $quick->link): ?>
                                    <a href="<?php echo esc_url( $quick->link ); ?>">
                                <?php endif; ?>
                                    
                                <?php if( $quick->icon ): ?>
                                    <i class="<?php echo esc_attr($quick->icon); ?>"></i>
                                <?php endif; ?>
                                
                                <?php if( $quick->val ): ?>
                                    <?php echo esc_html( $quick->val ); ?>
                                <?php endif; ?>

                                <?php if( $quick->link): ?>
                                    </a>
                                <?php endif; ?>
                            </li>
                        <?php
                    }
                }
	        ?>
                
        </ul>
		<?php
	}
endif;

if (! function_exists( 'business_roy_topheader_social' ) ):
	function business_roy_topheader_social($extra = null ){
		$social_icon = get_theme_mod('business_roy_topheader_social', json_encode(array(
            array(
                'icon' => 'fab fa-facebook',
                'link' => '#',
            ),
            array(
                'icon' => 'fab fa-twitter',
                'link' => '#',
            ),
            array(
                'icon' => 'fab fa-linkedin',
                'link' => '#',
            ),
            array(
                'icon' => 'fab fa-pinterest',
                'link' => '#',
            ),
            array(
                'icon' => 'fab fa-instagram',
                'link' => '#',
            ),
            array(
                'icon' => 'fab fa-youtube',
                'link' => '#',
            )
        )));

        echo '<ul class="sp_socialicon">';
        if (!empty( $social_icon ) ) :
            $social_icon = json_decode($social_icon);
                foreach ( $social_icon as $icon ) {
                    if( !$icon ) continue; 
                    if( isset( $icon->enable ) && ( $icon->enable == 'off' || $icon->enable == 'disabled') ) continue; ?>
	                <li>
	                	<a href="<?php if($icon->link) echo esc_url( $icon->link ); ?>" target="__blank"><i class="<?php echo esc_html( $icon->icon ); ?>"></i></a>
	                </li>
	            <?php }
        endif;
        if( $extra)  echo $extra;
        echo '</ul>';
	}
endif;
add_action('business_roy_social_icons', 'business_roy_topheader_social');


if (! function_exists( 'business_roy_contact_social_icons' ) ):
	function business_roy_contact_social_icons( ){
		$social_icon = get_theme_mod('business_roy_contact_social_link');
        echo '<ul class="sp_socialicon">';
        if (!empty( $social_icon ) ) :
            $social_icon = json_decode($social_icon);
         	    foreach ( $social_icon as $icon ) { if( !$icon->link ) continue; ?>
	                <li>
	                	<a href="<?php if($icon->link) echo esc_url( $icon->link ); ?>" target="__blank"><i class="<?php echo esc_html( $icon->icon ); ?>"></i></a>
	                </li>
	            <?php }
        endif;
        echo '</ul>';
	}
endif;
add_action('business_roy_contact_social_icons', 'business_roy_contact_social_icons');

function business_roy_quick_contact_info_header(){
    ?>
    <div class="contact-info">
        <div class="quickcontact">
            <?php
                $phone_number  = get_theme_mod('business_roy_contact_num');
                $phonenumber   = preg_replace('/\D+/','', $phone_number );
                $email_address = get_theme_mod('business_roy_email');
                $map_address   = get_theme_mod('business_roy_address');

                $quick_content = get_theme_mod('business_roy_quick_content', json_encode(array(
                    array(
                        'icon' => 'fas fa-phone-volume',
                        'label' => esc_html('Call Anytime 24/7','business-roy'),
                        'val' => '+01-559-236-8009',
                        'link' => '',
                    ),
                    array(
                        'icon' => 'fas fa-map-marker-alt',
                        'label' => esc_html('Office Address','business-roy'),
                        'val' => '28 Street, New York City',
                        'link' => '',
                    ),
                    array(
                        'icon' => 'far fa-envelope',
                        'label' => esc_html('Mail Us For Support','business-roy'),
                        'val' => 'info@ikreatethemes.com',
                        'link' => '',
                    )
                )));
                $quick_content = json_decode( $quick_content );
                if( is_array( $quick_content ) ){
                    foreach( $quick_content as $quick ){
                        ?>
                            <div class="get-tuch">
                                <?php if( $quick->link): ?>
                                    <a href="<?php echo esc_url( $quick->link ); ?>">
                                <?php endif; ?>
                                    
                                    <?php if( $quick->icon ): ?>
                                        <i class="<?php echo esc_attr($quick->icon); ?>"></i>
                                    <?php endif; ?>
                                
                                <?php if( $quick->link): ?>
                                    </a>
                                <?php endif; ?>
                                
                                <div class="quickcontactwrap">
                                    <?php if( $quick->label): ?>
                                        <div class="quickcontact-title">
                                            <?php echo esc_html( $quick->label ); ?>
                                        </div>
                                    <?php endif; ?>
                                    
                                    <?php if( $quick->val): ?>
                                        <span>
                                            <?php echo esc_html( $quick->val ); ?>
                                        </span>
                                    <?php endif; ?>
								</div>
                            </div>
                        <?php
                    }
                }
                
            ?>
        </div> <!--/ End Contact -->
    </div>
    <?php
}
add_action('business_roy_quick_contact_info_header', 'business_roy_quick_contact_info_header');


if (! function_exists( 'business_roy_topheader_free_hand' ) ):

    function business_roy_topheader_free_hand(){

        $free_hand = get_theme_mod('business_roy_topheader_free_hand','Need Any Help: +1-559-236-8009 or help@example.com');
        ?>
            <span><i class="far fa-dot-circle"></i> <?php echo esc_html( $free_hand ); ?></span>
    <?php }
endif;


/**
 * Breadcrumbs Section.
*/
if (! function_exists( 'business_roy_breadcrumbs' ) ):

    function business_roy_breadcrumbs(){

            $aligment = get_theme_mod('business_roy_titlebar_title_align','text-center');
           
            $service_class = array(
                'titlebar-section',
                'breadcrumb-section',
                'section',
                $aligment
            );
            ?>
            <section id="titlebar-section" class="<?php echo esc_attr(implode(' ', $service_class)) ?>">
                <div class="section-wrap">
                    <div class="container">
                        <div class="d-grid">
                            <div class="inner-section-wrap breadcrumb_wrapper">
                                <?php
                                    if(get_theme_mod('business_roy_show_title', true) ):

                                        if (is_single() || is_page()):

                                            the_title('<h2 class="section-title">', '</h2>');

                                        elseif (is_archive()):

                                            the_archive_title('<h2 class="section-title">', '</h2>');

                                        elseif (is_search()): ?>

                                            <h2 class="section-title">
                                                <?php printf(esc_html__('Search Results for:', 'business-roy'), '%s', '<span>' . get_search_query() . '</span>'); ?>
                                            </h2>

                                        <?php elseif (is_404()):
                                        
                                            echo '<h2 class="section-title">' . esc_html('404 Error', 'business-roy') . '</h2>';

                                        elseif (is_home()):

                                            $page_for_posts_id = get_option('page_for_posts');
                                            $page_title = get_the_title($page_for_posts_id);
                                    ?>
                                            <h2 class="section-title"><?php echo esc_html($page_title); ?></h2>
                                    
                                    <?php else: ?>

                                            <h2 class="section-title"><?php echo esc_html($page_title); ?></h2>
                                    <?php
                                    endif;

                                endif;

                                if( get_theme_mod('business_roy_breadcrumb', true)): ?>
                                    <nav id="breadcrumb" class="breadcrumb">
                                        <?php
                                            breadcrumb_trail(array(
                                                'container' => 'div',
                                                'show_browse' => false,
                                            ));
                                        ?>
                                    </nav>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
                <?php business_roy_add_bottom_seperator('titlebar'); ?>
            </section>
        <?php
    }
endif;
add_action('business_roy_breadcrumbs', 'business_roy_breadcrumbs', 100);

/**
 * Default Slider Function Area
*/
if (! function_exists( 'business_roy_banner_slider' ) ):

    function business_roy_banner_slider(){ 

        $all_slider = get_theme_mod('business_roy_banner_sliders');
        $banner_slider = json_decode( $all_slider );
        //if ($banner_slider && $banner_slider[0]->slider_page ) {
        if ( !empty( $banner_slider ) ) {

            $controls = get_theme_mod('slider-controls',  json_encode(array(
				'loop'   => 1,
				'autoplay'   => 1,
				'pager'   => 1,
				'controls'   => 1,
				'usecss'   => 1,
				'mode'   => 'fade',
				'csseasing'   => 'ease',
				'easing'   => 'linear',
				'slideendanimation'   => 1,
				'drag'   => 1,
				'speed'   => 5000,
				'pause'   => 4000
			)));
			$controls = json_decode($controls, true);
            $data = business_roy_get_data_attribute($controls);
        ?>
        <div class="banner-wrapper">
            <div class="slider-wrapper banner-slider">
                <div id="banner-slider" class="owl-carousel features-slider" <?php echo ( $data ); ?>>
                    <?php 
                        foreach ($banner_slider as $slider) {
                            $page_id = $slider->slider_page;
                        if (!empty($page_id)) {
                            $slider_page = new WP_Query('page_id=' . $page_id);
                            if ($slider_page->have_posts()) { while ($slider_page->have_posts()) { $slider_page->the_post();
                    ?>
                        <div class="background-image slider-item text-left" style="background-image: url(<?php the_post_thumbnail_url(); ?>);" data-img-url="<?php echo esc_url(get_the_post_thumbnail_url()); ?>">
                            <div class="banner-content-area">
                                <div class="container">
                                    <div class="inner-row d-flex">
                                        <div class="slider-content">
                                            <?php if( !empty( $slider->subtitile ) ): ?>
                                                <span class="supertitle"><?php echo esc_html($slider->subtitile); ?></span>
                                            <?php endif; ?>
                                            <h2 class="maintitle"><?php the_title(); ?></h2>
                                            <div class="maincontent"><?php the_excerpt(); ?></div>
                                            <div class="btn-area">
                                                <?php if (!empty( $slider->button_text ) ): ?>
                                                    <a href="<?php echo esc_url( $slider->button_url ); ?>" class="btn">
                                                        <?php echo esc_html( $slider->button_text ); ?>
                                                        <i class="fas fa-long-arrow-alt-right"></i>
                                                    </a>
                                                <?php endif; ?>
                                                <?php if (!empty( $slider->button_one_text ) ): ?>
                                                    <a href="<?php echo esc_url( $slider->button_one_url ); ?>" class="btn style-white">
                                                        <?php echo esc_html( $slider->button_one_text ); ?>
                                                        <i class="fas fa-long-arrow-alt-right"></i>
                                                    </a>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php } } } } ?>
                </div><!-- Slider section end -->
                <?php do_action("after_slider_section"); ?>    
            </div>
            
        </div>
    <?php } }

endif;
add_action('business_roy_action_banner_slider', 'business_roy_banner_slider', 5);


/**
 * Advance Slider Function Area
*/
if (! function_exists( 'business_roy_advance_banner_slider' ) ):

    function business_roy_advance_banner_slider(){ 

        $all_slider    = get_theme_mod('business_roy_slider_advance_settings');
        $banner_slider = json_decode( $all_slider );
        
        if( !empty( $banner_slider ) ) {

            $controls = get_theme_mod('slider-controls',  json_encode(array(
				'loop'   => 1,
				'autoplay'   => 1,
				'pager'   => 0,
				'controls'   => 1,
				'usecss'   => 1,
				'mode'   => 'fade',
				'csseasing'   => 'ease',
				'easing'   => 'linear',
				'slideendanimation'   => 1,
				'drag'   => 1,
				'speed'   => 5000,
				'pause'   => 4000
			)));
			$controls = json_decode($controls, true);
            $data = business_roy_get_data_attribute($controls);
        ?>
        <div class="banner-wrapper">
            <div class="slider-wrapper banner-slider">
                <div id="banner-slider" class="owl-carousel features-slider" <?php echo ($data); ?>>
                    <?php 
                        foreach ($banner_slider as $slider) {
                    ?>
                        <div class="background-image slider-item text-left" style="background-image: url(<?php echo esc_url($slider->block_image); ?>);" data-img-url="<?php echo esc_url(get_the_post_thumbnail_url()); ?>">
                            <div class="banner-content-area">
                                <div class="container">
                                    <div class="inner-row d-flex">
                                        <div class="slider-content">
                                            <?php if( !empty( $slider->block_subtitile ) ): ?>
                                                <span class="supertitle"><?php echo esc_html($slider->block_subtitile); ?></span>
                                            <?php endif; ?>
                                            <?php if( !empty( $slider->block_title ) ): ?>
                                                <h2 class="maintitle"><?php echo esc_html($slider->block_title); ?></h2>
                                            <?php endif; ?>
                                            <?php if( !empty( $slider->block_desc ) ): ?>
                                                <div class="maincontent">
                                                    <p><?php echo esc_html($slider->block_desc); ?></p>
                                                </div>
                                            <?php endif; ?>
                                            <div class="btn-area">
                                                <?php if (!empty( $slider->button_text ) ): ?>
                                                    <a href="<?php echo esc_url( $slider->button_url ); ?>" class="btn">
                                                        <?php echo esc_html( $slider->button_text ); ?>
                                                        <i class="fas fa-long-arrow-alt-right"></i>
                                                    </a>
                                                <?php endif; ?>
                                                <?php if (!empty( $slider->button_one_text ) ): ?>
                                                    <a href="<?php echo esc_url( $slider->button_one_url ); ?>" class="btn style-white">
                                                        <?php echo esc_html( $slider->button_one_text ); ?>
                                                        <i class="fas fa-long-arrow-alt-right"></i>
                                                    </a>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php } ?>
                </div>
                <?php do_action("after_slider_section"); ?>    
            </div>
            
        </div>
    <?php } }
endif;
add_action('business_roy_advance_slider', 'business_roy_advance_banner_slider', 10);

/**
 * Video Background Banner Function
*/
if ( ! function_exists( 'business_roy_video_background_banner' ) ) {

    function business_roy_video_background_banner(){

        $bg_video = get_theme_mod("business_roy_video_banner_url");
        
        if( $bg_video ):
          $video_data = 'data-property="{videoURL:\'' . $bg_video . '\', mobileFallbackImage:\'https://img.youtube.com/vi/' . $bg_video . '/maxresdefault.jpg\'}"';
        else: 
          $video_data = '';
        endif;
        ?>
        <div id="banner-slider" class="section banner-slider video-banner " <?php echo $video_data; ?>>  
            <!-- <div class="home-slider-overlay"></div> -->
            <?php do_action("after_slider_section"); ?>
        </div>
        <?php
    }
}
add_action( 'business_roy_video_banner', 'business_roy_video_background_banner', 15 );


/**
 * Slider Type
*/
if (! function_exists( 'business_roy_all_slider_type' ) ):
    function business_roy_all_slider_type(){ 
        $slider_type = get_theme_mod('business_roy_slider_type','default');
        switch ( $slider_type ) {
            case 'video':
                /**
                 * @hooked business_roy_video_banner - 15
                */
                do_action('business_roy_video_banner');
                break;
            case 'advance':
                    /**
                     * @hooked business_roy_advance_slider - 10
                    */
                    do_action('business_roy_advance_slider');
                    break;
            default:
                /**
                 * @hooked business_roy_action_banner_slider - 5
                */
                do_action('business_roy_action_banner_slider');
                break;
        }
    }
endif;
add_action('business_roy_slider_type', 'business_roy_all_slider_type', 25);


if (! function_exists( 'business_roy_service_title' ) ):
    function business_roy_service_title() {
        /**
         * Section Title
        */
        $supertitle = get_theme_mod( 'business_roy_promoservice_super_title', get_theme_mod( 'business_roy_service_subtitle' ) );
        $title 		= get_theme_mod('business_roy_promoservice_title', get_theme_mod( 'business_roy_service_title' ) );
        $titlestyle = get_theme_mod( 'business_roy_service_title_align','text-center' );
        
        business_roy_section_title( $supertitle, $title, $titlestyle ); 
    }
endif;

if (! function_exists( 'business_roy_service_title' ) ):
    function business_roy_service_title() {
        /**
         * Section Title
        */
        $supertitle = get_theme_mod( 'business_roy_service_title' );
        $title 		= get_theme_mod( 'business_roy_service_subtitle' );
        $titlestyle = get_theme_mod( 'business_roy_service_title_align','text-center' );
        business_roy_section_title( $supertitle, $title, $titlestyle ); 
    }
endif;

/*****
 * After Slider Section 
*/
function add_slider_bottom_section_seperator() {
    if( get_theme_mod('business_roy_slider_section_seperator', 'no') == 'bottom'):
        
        $bottom_seperator = get_theme_mod("business_roy_slider_bottom_seperator", 'water-waves');
        
        echo '<div class="section-seperator bottom-section-seperator svg-' . $bottom_seperator . '-wrap">';
            get_template_part("inc/svg/{$bottom_seperator}");
        echo '</div>';
        
    endif;
}
add_action("after_slider_section", "add_slider_bottom_section_seperator");

/*****
 * After Footer Section 
*/
if(!function_exists('business_roy_add_footer_seperator')){
    function business_roy_add_footer_seperator() {
        if( get_theme_mod('business_roy_footer_section_seperator', 'no') == 'top'):
            
            $footer_top_seperator = get_theme_mod("business_roy_footer_top_seperator", 'water-waves');
            
            echo '<div class="section-seperator bottom-section-seperator svg-' . $footer_top_seperator . '-wrap">';
                get_template_part("inc/svg/{$footer_top_seperator}");
            echo '</div>';
            
        endif;
    }
}

if(!function_exists('business_roy_add_top_seperator')):

    function business_roy_add_top_seperator($section_name) {

        $section_seperator = get_theme_mod("business_roy_{$section_name}_section_seperator", "no");
        
        if ($section_seperator == 'top' || $section_seperator == 'top-bottom') {
            $top_seperator = get_theme_mod("business_roy_{$section_name}_top_seperator", 'big-triangle-center');
            echo '<div class="section-seperator top-section-seperator svg-' . $top_seperator . '-wrap">';
            get_template_part("inc/svg/{$top_seperator}");
            echo '</div>';
        }
    }
endif;

if(!function_exists('business_roy_add_bottom_seperator')):

    function business_roy_add_bottom_seperator($section_name) {

        $section_seperator = get_theme_mod("business_roy_{$section_name}_section_seperator", "no");

        if ($section_seperator == 'bottom' || $section_seperator == 'top-bottom') {

            $bottom_seperator = get_theme_mod("business_roy_{$section_name}_bottom_seperator", 'big-triangle-center');
            echo '<div class="section-seperator bottom-section-seperator svg-' . $bottom_seperator . '-wrap">';
                get_template_part("inc/svg/{$bottom_seperator}");
            echo '</div>';
        }
    }
endif;


if(!function_exists('business_roy_parallax_background')):

    function business_roy_parallax_background($section_name = '') {

        $bg_type = get_theme_mod("business_roy_{$section_name}_bg_type");
        $bg_image = get_theme_mod("business_roy_{$section_name}_bg_image_url");
        $bg_video = get_theme_mod("business_roy_{$section_name}_bg_video", '6O9Nd1RSZSY');
        $parallax_mode = '';
        if ($bg_type == "video-bg" && !empty($bg_video)) {
            $parallax_mode = 'data-property="{videoURL:\'' . $bg_video . '\', mobileFallbackImage:\'https://img.youtube.com/vi/' . $bg_video . '/maxresdefault.jpg\'}"';
        }
        return $parallax_mode;
    }
endif;

/**
 * Dynamic class generate for alignment
 */
if(!function_exists('get_business_roy_alignment_class')){
    function get_business_roy_alignment_class($align){
        if($align){
            $align = json_decode($align);
            if(is_object($align)){
                $css = "desktop-".$align->desktop;
                if($align->tablet) $css .= " tablet-".$align->tablet ;
                if($align->mobile) $css .=  " mobile-".$align->mobile;
                return $css;
            }
        }
    }
}
if( !function_exists( 'business_roy_get_data_attribute' )){
    function business_roy_get_data_attribute($controls){
      $data = "";
      foreach($controls as $k => $v){
        $data .=" data-{$k}='". esc_attr( $v ) ."'";
      }
      
      return $data;
    }
}

if( !function_exists( 'business_roy_get_scroll_down')){
    function business_roy_get_scroll_down(){
        ?>
        <div class="scroll-downs">
            <div class="mousey">
                <div class="scroller"></div>
            </div>
        </div>
    <?php
    }
    add_action('business_roy_banner_after_content', 'business_roy_get_scroll_down');
}


if( !function_exists('business_roy_contact_info_section')){
    function business_roy_contact_info_section(){

        $details = get_theme_mod('business_roy_contact_details');
        $details = json_decode($details, true);

        if( is_array($details) && count($details) > 0 ): 
        ?>
        <div class="get-touch-contact">
            <?php 
                foreach($details as $contact ): 
                    if( empty($contact['icon']) && empty($contact['label']) && empty($contact['description'])) continue;
            ?>
                <div class="get-touch">
                    <?php if( $contact['icon']): ?>
                    <div class="get-touch-icon">
                        <i class="<?php echo esc_attr($contact['icon']); ?>"></i>
                    </div>
                    <?php endif; ?>

                    <div class="get-tuch-info">
                        <?php if( $contact['label']): ?>
                            <div class="get-tuch-title"><?php echo esc_html($contact['label']); ?></div>
                        <?php endif; ?>
                        <?php if($contact['description']): ?>
                        <p><?php echo esc_html($contact['description']); ?></p>
                        <?php endif; ?>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        <?php
        endif;
    }
    add_action('business_roy_contact_info_section', 'business_roy_contact_info_section');
}


if( !function_exists( 'business_roy_footer_main_content' ) ) {
    function business_roy_footer_main_content() {

        if (is_active_sidebar( 'footer-1' ) ): ?>
            <div class="footer-section-wrapper">
                <div class="footer-seprator">
                    <?php business_roy_add_footer_seperator('footer'); ?>
                </div>
                <footer id="footer-section" class="footer-section site-footer">
                    <div class="container">
                        <div class="d-grid <?php echo esc_attr(get_theme_mod('business_roy_footer_column', 'd-grid-column-3')); ?>">
                            <?php
                                for ($i = 1; $i <= 4; $i++) {
                                    if (is_active_sidebar('footer-' . $i)) { ?>
            
                                        <?php dynamic_sidebar('footer-' . $i); ?>
                                        
                            <?php } } ?>
                        </div>
                    </div>
                </footer><!-- #colophon -->
            </div>
        <?php endif; 

    }
}