<?php
/**
 * Template part for displaying front page section
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Business Roy
 */
/**
 * Hook -  business_roy_action_about
 *
 * @hooked business_roy_action_about - 35
*/
/**
 * About Us Section.
*/

if( !function_exists('get_about_us_image')):
    function get_about_us_image($about_image, $text_align="text-left"){
        //if (!empty($about_image)): ?>
            <div class="about-left <?php echo esc_attr($text_align); ?> about-img" data-aos="fade-left" data-aos-duration="1500">
                <img src="<?php echo esc_url(  $about_image  ); ?>"/>
            </div>
        <?php //endif;
    }
endif;

if( !function_exists('get_about_us_content') ):

    function get_about_us_content($text_align = "text-left", $about_image = false){
        
        $super_title = get_theme_mod('business_roy_aboutus_super_title');
        ?>
        <div class="about-right <?php echo esc_attr( $text_align ); ?> " data-aos="fade-right" data-aos-duration="1500">
            <span class="aboutsuper-title"><?php echo esc_html( $super_title ); ?></span>
            <h2 class="section-title"><?php the_title(); ?></h2>
            <div class="section-tagline-text">
                <?php the_content(); ?>
                <?php
                    if (get_theme_mod('business_roy_aboutus_progressbar', 'enable') == 'enable'):

                        $about_progressbar = get_theme_mod('business_roy_progressbar');
                        
                        if (!empty( $about_progressbar ) ): 
                ?>
                        <div class="achivement-items">
                            <ul>
                                <?php
                                    $progressbars = json_decode($about_progressbar);
                                    foreach ($progressbars as $progressbar):
                                        if( $progressbar->progressbar_title || $progressbar->icon || $progressbar->progressbar_number):
                                ?>
                                    <li>
                                        <?php if( $progressbar->icon): ?>
                                            <div class="timer-icon">
                                                <i class="<?php echo esc_attr( $progressbar->icon ); ?>"></i>
                                            </div>
                                        <?php endif; ?>
                                        <div class="timer-content">
                                            <?php if( $progressbar->progressbar_number ): ?>
                                                <div class="timer achivement"><?php echo intval( $progressbar->progressbar_number ); ?></div>
                                            <?php endif; ?>
                                            <span class="medium"><?php echo esc_html( $progressbar->progressbar_title ); ?></span>
                                        </div>
                                    </li>
                                <?php endif; endforeach; ?>
                            </ul>
                        </div>
                    <?php endif; endif;

                    $about_button = get_theme_mod( 'business_roy_aboutus_button_text','More About Us' );
                    
                    if ( $about_button ) { ?>
                        <a href="<?php the_permalink(); ?>" class="btn btn-primary">
                            <?php echo esc_html( $about_button ); ?><i class="fas fa-long-arrow-alt-right"></i>
                        </a>
                    <?php }
                    $signature = get_theme_mod('business_roy_aboutus_signature');
                    $image = get_theme_mod('business_roy_aboutus_profile_image');
                    $profile_name = get_theme_mod('business_roy_aboutus_profile_name');
                    if( $image ): ?>
                        <div class="about-profile">
                            <?php if( !empty( $image )): ?>
                                <div class="about-profile-img" style="background-image: url('<?php echo esc_url($image); ?>')"></div>
                            <?php endif; ?>
                            
                            <?php if( $profile_name ): ?>
                                <div class="profile-info">
                                    <h4><?php echo esc_html($profile_name ); ?></h4>
                                    <?php if($profile_role = get_theme_mod('business_roy_aboutus_profile_role') ): ?>
                                        <span class="role"><?php echo esc_html( $profile_role ); ?></span>
                                    <?php endif; ?>
                                </div>
                            <?php endif; ?>

                            <?php if( !empty( $signature ) ): ?>
                                    <div class="about-signature">
                                        <img src="<?php echo esc_url($signature); ?>" alt="signature">
                                    </div>
                            <?php endif; ?>
                        </div>
                    <?php endif; ?>
            </div>
        </div>
        <?php
    }
endif;

if (! function_exists( 'business_roy_about' ) ):
    function business_roy_about(){ 
        $aboutus_options = get_theme_mod('business_roy_aboutus_service_section','enable');
        if( !empty( $aboutus_options ) && $aboutus_options == 'enable' ){
            $business_roy_service_style = get_theme_mod('business_roy_aboutus_layout_design', 'layouttwo');
            $service_class = array(
                $business_roy_service_style,
                'section',
                'aboutus-section',
                'about_us_front'
            );
            ?>
            <section id="aboutus-section" class="<?php echo esc_attr(implode(' ', $service_class)) ?>">
                <?php business_roy_add_top_seperator('aboutus'); ?>
                <div class="section-wrap">
                    <div class="container">
                        <div class="about-wrapper inner-section-wrap">
                            <?php
                                $aboutus = get_theme_mod('business_roy_about');
                                if (!empty( $aboutus ) ):
                                $aboutus_args = array(
                                    'posts_per_page' => 1,
                                    'post_type' => 'page',
                                    'page_id' => $aboutus,
                                    'post_status' => 'publish',
                                );
                                $aboutus_query = new WP_Query($aboutus_args);
                                
                                if ( $aboutus_query->have_posts() ) : while ( $aboutus_query->have_posts() ) : $aboutus_query->the_post();
                                    
                                $about_image = get_theme_mod('business_roy_about_image');
                                
                                get_about_us_image( $about_image );

                                get_about_us_content( $about_image );
                            ?>
                            <?php endwhile; endif; endif; ?>
                        </div>
                    </div>
                </div>
                <?php business_roy_add_bottom_seperator('aboutus'); ?>
            </section>
    <?php } }
endif;
add_action('business_roy_action_about', 'business_roy_about', 35);

do_action('business_roy_action_about');