<?php
/**
 * Template part for displaying front page section
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Business Roy
 */
 /**
 * Hook -  business_roy_action_calltoaction
 *
 * @hooked business_roy_calltoaction - 50
 */
/**
 * Call To Action Section.
*/
if (! function_exists( 'business_roy_calltoaction' ) ):
    
    function business_roy_calltoaction(){
        
        $cta_title       = get_theme_mod( 'business_roy_call_to_action_title' );
        $cta_sub_title   = get_theme_mod( 'business_roy_call_to_action_subtitle' );
        $button_text     = get_theme_mod('business_roy_call_to_action_button');
        $button_text_one = get_theme_mod('business_roy_call_to_action_button_one');
        $button_link = get_theme_mod('business_roy_call_to_action_link');
        $button_link_one = get_theme_mod('business_roy_call_to_action_link_one');
        $cta_options = get_theme_mod('business_roy_cta_service_section','enable');
        
        if( !empty( $cta_options ) && $cta_options == 'enable' ){
            $service_class = array(
                'section',
                'calltoaction-section',
                'calltoaction_promo_wrapper',
                'calltoaction',
                get_theme_mod('business_roy_cta_alignment', 'text-center')
            );
            
            $reverse = get_theme_mod('business_roy_cta_layout', 'cta-left');
            $about_image = get_theme_mod('business_roy_calltoaction_image');
            
            $class = '';
            if( $about_image ){
                $class = ' withimage ';
            }
            $class .= $reverse;

            ?>
            <section id="calltoaction-section" class="<?php echo esc_attr(implode(' ', $service_class)) ?>">
                <?php business_roy_add_top_seperator('calltoaction'); ?>
                <div class="section-wrap">
                    <div class="container">
                        <div class="inner-section-wrap cta-innerwrapper <?php echo esc_attr( $class ); ?>">
                            <div class="cat-content-wrap" data-aos="fade-up" data-aos-duration="1500">
                                <div class="calltoaction_full_widget_content">
                                    <h2 class="section-title"><?php echo esc_html( $cta_title ); ?></h2>
                                    <p class="calltoaction_subtitle section-text"><?php echo esc_html( $cta_sub_title ); ?></p>
                                    <div class="calltoaction_button_wrap">
                                        <?php if( !empty( $button_text ) ){ ?>
                                            <a href="<?php echo esc_url( $button_link ); ?>" class="btn btn-primary">
                                                <?php echo esc_html( $button_text ); ?> <i class="fas fa-long-arrow-alt-right"></i>
                                            </a>
                                        <?php } if( !empty( $button_text_one ) ){ ?>
                                            <a href="<?php echo esc_url( $button_link_one ); ?>" class="btn btn-border">
                                                <?php echo esc_html( $button_text_one ); ?> <i class="fas fa-long-arrow-alt-right"></i>
                                            </a>
                                        <?php } ?>
                                    </div>
                                </div>
                            </div>
                            <?php if( !empty( $about_image ) ): ?>
                                <div class="cat-image-wrap" data-aos="fade-up" data-aos-duration="1500" data-aos-delay="100">
                                    <img src="<?php echo ( $about_image); ?>">
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                <?php business_roy_add_bottom_seperator('calltoaction'); ?>
            </section>
    <?php } }
endif;
add_action('business_roy_action_calltoaction', 'business_roy_calltoaction', 50);

do_action('business_roy_action_calltoaction');