<?php
/**
 * Template part for displaying front page section
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Business Roy
 */
if( !function_exists('business_roy_contact_content')){

 function business_roy_contact_content() {

    $contact_shortcode = get_theme_mod('business_roy_contact_shortcode');
    $show_icons = get_theme_mod('business_roy_contact_social_icons', 'enable');
    $show_contact_box = get_theme_mod('business_roy_show_contact_detail', 'enable');
    
    if ($show_contact_box == 'enable') {
        ?>
        <div class="contact-detail-toggle open"><i class="fa fa-plus" aria-hidden="true"></i></div>
            <div class="contact-content" data-aos="fade-up" data-aos-duration="1500" data-aos-delay="100">
                <?php 
                    business_roy_add_top_seperator('contact'); 
                    $title = get_theme_mod('business_roy_contact_title', __('Quick Get In Touch', 'business-roy'));
                    $description = get_theme_mod('business_roy_contact_descripton');
                ?>
                <div class="contact-form">
                    <?php if( $title ): ?>
                        <h3 class="section-title"><?php echo esc_html( $title); ?></h3>
                    <?php endif; ?>
                    <?php if( $description ): ?>
                        <p class="contact-desc"><?php echo esc_html( $description); ?></p>
                    <?php endif; ?>
                    <?php echo do_shortcode($contact_shortcode); ?>
                </div>
                <div class="contact-detail">
                    <?php 
                        $heading = get_theme_mod('business_roy_contact_details_right_heading', 'Quick Contact Information');
                        if(!empty( $heading ) ): 
                    ?>
                        <h3><?php echo esc_html($heading); ?></h3>
                    <?php endif; ?>

                    <?php do_action('business_roy_contact_info_section'); ?>
                    
                    <?php  if ( $show_icons == 'enable' ) {  ?>
                        <div class="contact-social-icon">
                            <?php do_action('business_roy_contact_social_icons'); ?>
                        </div>
                    <?php } ?>
                </div>
                <?php business_roy_add_bottom_seperator('contact'); ?>
            </div>
        <?php
    }
 }
}
if( !function_exists('business_roy_contact_map')){
function business_roy_contact_map() {
    $latitude = get_theme_mod('business_roy_latitude', 24.691943);
    $longitude = get_theme_mod('business_roy_longitude', 78.403931);
    $map_key = get_theme_mod('google_api_key', 'AIzaSyCAIwTPctnSM2PWcbK6cMdlZaSgEYIKp5U');
    ?>
        <div id="google-map">
            
        </div>
    <?php
    if (!empty($longitude) && !empty($latitude) && $map_key ) {
        ?>
        <script src="https://maps.googleapis.com/maps/api/js?key=<?php echo esc_attr($map_key); ?>&callback=initMap" async defer></script>
        <script>
            var center = { lat: <?php echo $latitude; ?>, lng: <?php echo $longitude; ?>};
            function initMap() {
                var options = {     
                    zoom: 10,
                    center: center
                }
                var map = new google.maps.Map(document.getElementById('google-map'), options);

                var marker = new google.maps.Marker({
                    position: center,
                    map: map
                });
            }
        </script>
        <?php
    }
}}
if( !function_exists('business_roy_contact_section')){
function business_roy_contact_section() {

    if (get_theme_mod('business_roy_contact_section_disable', 'disable') == 'enable') {
        $show_contact_box = get_theme_mod('business_roy_show_contact_detail', 'enable');
        $contact_class = array('section', 'contact-section');
        $contact_class[] = 'contact-detail-' . esc_attr($show_contact_box);
        ?>
        <section id="contact-section" class="<?php echo implode(' ', $contact_class); ?>">
            <div class="section-wrap">
                <div class="contact-google-map">
                    <?php business_roy_contact_map(); ?>
                </div>
                <?php if(!empty( $show_contact_box && $show_contact_box ='enable' ) ){ ?>
                    <div class="container">
                        <div class="inner-section-wrap">
                            <?php business_roy_contact_content(); ?>
                        </div>
                    </div>
                <?php } ?>
            </div>
        </section>
        <?php
    }
}
}
add_action('business_roy_contact', 'business_roy_contact_section', 30);

 /**
 * Hook -  business_roy_contact
 *
 * @hooked business_roy_contact - 30
 */
do_action('business_roy_contact');