<?php
/**
 * Template part for displaying front page section
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 */
if( !function_exists('business_roy_how_it_works_default_content')){
    function business_roy_how_it_works_default_content($steps){
        foreach($steps as $index => $step): 
            if( $step->block_page == '' ) continue;
            ?>
            <li data-aos="fade-up" data-aos-duration="1500" data-aos-delay="100">
                <div class="step_text">
                    <h4><a href="<?php the_permalink(); ?>"><?php echo esc_html( get_the_title( $step->block_page ) ); ?></a></h4>
                    <?php the_excerpt(); ?>
                    <a href="<?php the_permalink(); ?>" class="btn btn-noborder">
                        <?php echo esc_html( 'Read More','business-roy' ); ?> <i class="fas fa-long-arrow-alt-right"></i>
                    </a>
                </div>
                <div class="step_number">
                    <h2>
                        <?php 
                            $value = str_pad(++$index,2,"0",STR_PAD_LEFT);
                            echo esc_html($value);
                        ?>
                    </h2>
                </div>
                <div class="step_img">
                    <?php
                        $img = get_the_post_thumbnail_url($step->block_page, 'medium_large');
                        if( $img ) {
                            echo '<img src="'. esc_url($img ). '" alt="'. get_the_title() .'"/>';       
                        } 
                    ?>
                </div>
            </li>
            <?php endforeach; ?>
        <?php
    }   
}

/*****
 * Advance How It Works
 */
if( !function_exists('business_roy_how_it_works_advance_content')){
    function business_roy_how_it_works_advance_content($steps){
        foreach($steps as $index => $step): 
            if( $step->block_title == '' ) continue;
            ?>
            <li data-aos="fade-up" data-aos-duration="1500" data-aos-delay="100">
                <div class="step_text">
                    <h4><a href="<?php echo esc_url( $step->button_url ); ?>"><?php echo esc_html( $step->block_title ); ?></a></h4>
                    <p><?php echo esc_html( $step->block_desc ); ?></p>
                    <?php if( !empty( $step->button_text ) ){ ?>
                        <a href="<?php echo esc_url( $step->button_url ); ?>" class="btn btn-noborder">
                            <?php echo esc_html( $step->button_text ); ?> <i class="fas fa-long-arrow-alt-right"></i>
                        </a>
                    <?php } ?>
                </div>
                <div class="step_number">
                    <h2>
                        <?php 
                            $value = str_pad(++$index,2,"0",STR_PAD_LEFT);
                            echo esc_html($value);
                        ?>
                    </h2>
                </div>
                <div class="step_img">
                    <?php
                        $attachment_id = attachment_url_to_postid( $step->block_image );
                        if( $attachment_id ){
                            $img = wp_get_attachment_image_url( attachment_url_to_postid( $step->block_image ), 'medium_large' );
                        }else{
                            $img = $step->block_image;
                        }
                        if( $img ) {
                            echo '<img src="'. esc_url($img ). '" alt="'. get_the_title() .'"/>';       
                        } 
                    ?>
                </div>
            </li>
            <?php endforeach; ?>
        <?php
    }   
}

if (! function_exists( 'business_roy_how_it_works_area' ) ):
    function business_roy_how_it_works_area() {
        $section = get_theme_mod('business_roy_how_it_works_section_disable','disable');
        if( !empty( $section ) && $section != 'enable' )return;
        ?>
        <section id="how_it_works-section" class="how_it_works section">
            <?php 
                /**
                 * Section Title
                */
                $supertitle = get_theme_mod( 'business_roy_how_it_works_super_title');
                $title 		= get_theme_mod( 'business_roy_how_it_works_title');
                $titlestyle = get_theme_mod( 'business_roy_how_it_works_title_align','text-center');
                
                $howitworks_type = get_theme_mod('business_roy_how_it_works_type','default');
                if( $howitworks_type == 'default' ){
                    $steps = get_theme_mod('business_roy_how_it_works_page');
                }elseif( $howitworks_type == 'advance' ){
                    $steps = get_theme_mod('business_roy_how_it_works_advance_settings');
                }else{
                    $steps = get_theme_mod('business_roy_how_it_works_page');
                }

                if( $steps ){
                    $steps = json_decode($steps);
                }
                if( $steps): ?>
                    <?php business_roy_add_top_seperator('how_it_works'); ?>
                    <div class="section-wrap">
                        <div class="container">
                            <div class="inner-section-wrap">
                                <?php business_roy_section_title( $supertitle, $title, $titlestyle );  ?>
                                <div class="step_block">
                                    <ul>
                                        <?php 
                                            if( $howitworks_type == 'default' ){
                                                business_roy_how_it_works_default_content( $steps ); 
                                            }elseif( $howitworks_type == 'advance' ){
                                                business_roy_how_it_works_advance_content( $steps ); 
                                            }else{
                                                business_roy_how_it_works_default_content( $steps );
                                            }
                                        ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php business_roy_add_bottom_seperator('how_it_works'); ?>
                <?php endif; ?>
        </section>
        <?php
    }
endif;
add_action('business_roy_how_it_works', 'business_roy_how_it_works_area', 55);

do_action('business_roy_how_it_works');