<?php
/**
 * Template part for displaying front page section
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Business Roy
 */
/**
 * Hook -  business_roy_action_promo_service
 *
 * @hooked business_roy_promo_service - 30
 */
/**
 * Our Service Featues Section.
*/
if (! function_exists( 'business_roy_promo_service' ) ):

    function business_roy_promo_service(){

        $features_options = get_theme_mod('business_roy_promoservice_section','enable');
        
        $style = get_theme_mod('business_roy_promoservice_style', 'style1');
        
        if( !empty( $features_options ) && $features_options == 'enable' ){
            $service_class = array(
                'section',
                'promoservice-section',
                $style
            );
            ?>
            <section id="promoservice-section" class="<?php echo esc_attr(implode(' ', $service_class)) ?>">
                <?php business_roy_add_top_seperator('promoservice'); ?>
                <div class="section-wrap">
                    <div class="container">
                        <div class="inner-section-wrap">
                            <?php 
                                /**
                                 * Section Title
                                */
                                business_roy_service_title(); 
                            ?>
                            <div class="promoservice-wrap d-grid d-grid-column-3">
                                <?php
                                    $promoservice_type = get_theme_mod('business_roy_promoservice_type','default');
                                    
                                    switch ( $promoservice_type ) {
                                        case 'advance':
                                            /**
                                             * Advance Promo Service Function
                                            */
                                            business_roy_promo_advance_sections();
                                            break;

                                        default:
                                            /**
                                             * Default Promo Service Function
                                            */
                                            business_roy_promo_default_sections();
                                            break;
                                    }
                                ?>
                            </div>
                        </div>
                    </div>
                </div>
                <?php business_roy_add_bottom_seperator('promoservice'); ?>
            </section>
        <?php } }
endif;

add_action('business_roy_action_promo_service', 'business_roy_promo_service', 30);

/****
 * Default Promo Service
 */
if(!function_exists('business_roy_promo_default_sections')):
    function business_roy_promo_default_sections(){
        $promo_service  = get_theme_mod('business_roy_promoservice');
        $show_image = get_theme_mod('business_roy_promoservice_show_image', 'enable');
        if (!empty($promo_service)):
        $pages = json_decode($promo_service);
        foreach ($pages as $page):
        $page_id = $page->service_page;
        if (!empty($page_id)):
            $service_query = new WP_Query('page_id=' . $page_id);
            if ( $service_query->have_posts() ): while ( $service_query->have_posts() ): $service_query->the_post();
            
            if( !isset($page->bg_color)){
                $page->bg_color = '';
            }
            if( !isset($page->alignment)){
                $page->alignment = 'text-center';
            }
            
            $bg_color = $page->bg_color;
            $style = '';
            if( $bg_color ){
                $style = "style=background-color:{$bg_color};";
            }
        ?>
        <div class="feature-list box-shadow" data-aos="fade-up" data-aos-duration="1500" <?php echo esc_attr($style); ?>>
            <div class="box <?php echo esc_attr( $page->alignment); ?> <?php if(has_post_thumbnail() ): ?>image-<?php echo esc_attr($show_image); endif; ?> ">
                <?php if( has_post_thumbnail() && $show_image == 'enable' ): ?>
                    <figure>
                        <a href="<?php the_permalink(); ?>">
                            <?php the_post_thumbnail('post-thumbnail'); ?>
                        </a>
                    </figure>
                <?php endif; ?>
                <div class="bottom-content">
                    <div class="top-content-wrap">
                        <?php if( !empty( $page->service_icon ) ){ ?>
                            <div class="icon-box">
                                <i class="<?php echo esc_html( $page->service_icon ); ?>"></i>
                            </div>
                        <?php } ?>
                        <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
                    </div>
                    <div class="bottom-content-wrap">
                        <?php the_excerpt(); ?>
                        <a href="<?php the_permalink(); ?>" class="btn btn-noborder"><?php echo esc_html__('Read More', 'business-roy'); ?> <i class="fas fa-long-arrow-alt-right"></i></a>
                    </div>
                </div>
            </div>
            <div class="content-overlay"></div>
        </div>
        <?php   endwhile;  endif; endif; endforeach; endif;
    }
endif;

/****
 * Advance Promo Service
 */
if( !function_exists('business_roy_promo_advance_sections') ):
    
    function business_roy_promo_advance_sections(){
        
        $promo_service  = get_theme_mod('business_roy_promoservice_advance_settings');
        $show_image     = get_theme_mod('business_roy_promoservice_show_image', 'enable');

        if (!empty($promo_service)):

        $pages = json_decode($promo_service);

        foreach ($pages as $page):
            $block_title = $page->block_title;
            $block_image = $page->block_image;

            if (!empty($block_title)):

                if( !isset($page->block_bg_color)){
                    $page->block_bg_color = '';
                }
                if( !isset($page->block_alignment)){
                    $page->block_alignment = 'text-center';
                }
                
                $bg_color = $page->block_bg_color;
                $style = '';
                if( $bg_color ){
                    $style = "style=background-color:{$bg_color};";
                }
        ?>
            <div class="feature-list box-shadow" data-aos="fade-up" data-aos-duration="1500" <?php echo esc_attr($style); ?>>
                <div class="box <?php echo esc_attr( $page->block_alignment); ?> <?php if( $block_image ): ?>image-<?php echo esc_attr($show_image); endif; ?> ">
                    <?php if( $block_image && $show_image == 'enable' ): ?>
                        <figure>
                            <a href="<?php echo esc_url( $page->button_url ); ?>">
                                <img alt="<?php echo esc_html( $page->block_title ); ?>" src="<?php echo esc_url( $block_image ) ?>"  />
                            </a>
                        </figure>
                    <?php endif; ?>
                    <div class="bottom-content">
                        <div class="top-content-wrap">
                            <?php if( !empty( $page->block_icon ) ){ ?>
                                <div class="icon-box">
                                    <i class="<?php echo esc_html( $page->block_icon ); ?>"></i>
                                </div>
                            <?php } ?>
                            <h4><a href="<?php echo esc_url( $page->button_url ); ?>"><?php echo esc_html( $page->block_title ); ?></a></h4>
                        </div>
                        <div class="bottom-content-wrap">
                            <p><?php echo esc_html( $page->block_desc ); ?></p>
                            <?php if( !empty( $page->button_text ) ){ ?>
                                <a href="<?php echo esc_url( $page->button_url ); ?>" class="btn btn-noborder">
                                    <?php echo esc_html( $page->button_text ); ?> <i class="fas fa-long-arrow-alt-right"></i>
                                </a>
                            <?php } ?>
                        </div>
                    </div>
                </div>
                <div class="content-overlay"></div>
            </div>
        <?php endif; endforeach; endif;
    }
endif;

do_action('business_roy_action_promo_service');