<?php
/**
 * Template part for displaying front page section
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Business Roy
 */
 /**
 * Hook -  business_roy_action_recentwork
 *
 * @hooked business_roy_recentwork - 55
 */
 /**
 *  Our Work Portfolio Section.
*/
if (! function_exists( 'business_roy_recentwork_default' ) ):

    function business_roy_recentwork_default() {

        $title_style = get_theme_mod('business_roy_recentwork_title_align', 'text-center');
        $super_title = get_theme_mod('business_roy_gallery_subtitle');
        $title = get_theme_mod('business_roy_gallery_title');
        
        $portfolio_options = get_theme_mod('business_roy_portfolio_section','enable');
        if( !empty( $portfolio_options ) && $portfolio_options == 'enable' ){
        ?>
            <section id="recentwork-section" class="recentwork-section section">
                <?php business_roy_add_top_seperator('recentwork'); ?>
                <div class="section-wrap">
                    <div class="container">
                        <div class="inner-section-wrap">
                            <?php business_roy_section_title( $super_title, $title, $title_style ); ?>
                            <?php 
                                $recentwork_type = get_theme_mod('business_roy_recentwork_type','default');
                                switch ( $recentwork_type ) {
                                    case 'advance':
                                        /**
                                         * Advance Promo Service Function
                                        */
                                        business_roy_recentwork_advance_sections();
                                        break;

                                    default:
                                        /**
                                         * Default Promo Service Function
                                        */
                                        $layout = get_theme_mod('business_roy_recentwork_layout', 'layout-two');

                                        if( $layout == 'layout-one'):
                                            business_roy_slider_gallery();
                                        else:
                                            business_roy_normal_gallery();
                                        endif;

                                    break;
                                }
                            ?>
                        </div>
                    </div>
                </div>
                <?php business_roy_add_bottom_seperator('recentwork'); ?>
            </section>
    <?php } }
endif;

/****
 * Advance Portfolio 
 */
if( !function_exists('business_roy_recentwork_advance_sections')){

    function business_roy_recentwork_advance_sections(){ 
        
        $layout = get_theme_mod('business_roy_recentwork_layout', 'layout-two');
    ?>

    <div class="recentwork-wrap d-grid d-grid-column-4 <?php if( $layout == 'layout-one'){ echo esc_attr('portfolio-slider owl-carousel'); } ?>">
        <?php
            $recentwork_page  = get_theme_mod('business_roy_recentwork_page');
            if (!empty($recentwork_page)):
            $pages = json_decode($recentwork_page);

            foreach ($pages as $page):

                $page_id = $page->service_page;

                if (!empty($page_id)):
                    
                    $service_query = new WP_Query('page_id=' . $page_id);
                    
                    if ( $service_query->have_posts() ): while ( $service_query->have_posts() ): $service_query->the_post();
                ?>
                <div class="recentwork-list">
                    <figure>
                        <?php the_post_thumbnail(); ?>
                    </figure>
                    <div class="content-wrap">
                        <h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
                        <div class="bottom-wrap">
                            <a href="<?php the_permalink(); ?>" class="btn btn-noborder">
                                <?php echo esc_html__('Read More', 'business-roy'); ?> <i class="fas fa-long-arrow-alt-right"></i>
                            </a>
                        </div>
                    </div>
                    <div class="content-overlay"></div>
                </div>
            <?php endwhile;  endif; endif; endforeach; endif;
        ?>
    </div>

    <?php 
    }
}

if( !function_exists('business_roy_slider_gallery')){
    function business_roy_slider_gallery(){ ?>
        <div id="portfolio-slider" class="owl-carousel portfolio-slider">
            <?php
                $gallery = get_theme_mod('business_roy_image_gallery');
                $gallery = explode(',', $gallery);
                if( $gallery ):
                    foreach($gallery as $id ):
                        $url = wp_get_attachment_url($id);
                        if( $url ): ?>
                            <div class="item screen-img">
                                <img src="<?php echo esc_url($url); ?>" alt="Image">
                            </div>
                        <?php
                        endif;
                    endforeach;
                endif;
            ?>
        </div>
        <?php
    }
}

if( !function_exists('business_roy_normal_gallery')){
    function business_roy_normal_gallery(){ ?>

    <div class="gallery-wrapper d-grid d-grid-column-4" data-aos="fade-up" data-aos-duration="1500" data-aos-delay="100">

        <?php
            $gallery = get_theme_mod('business_roy_image_gallery');
            $gallery = explode(',', $gallery);
            
            foreach($gallery as $id ):
                $url = wp_get_attachment_image_url($id, 'full');
                $thumbnail = wp_get_attachment_image_url($id, 'medium_large', true);
                
                if( $url ): ?>
                    <div class="gallery-item">
                        <div class="gallery-item-wrapper">
                            <a href="<?php echo esc_url($url); ?>" title="Gallery Image"  class="btn-wrap" rel="portfolio[work]">
                                <img src="<?php echo esc_url($thumbnail); ?>" alt="Gallery Image">
                                <div class="caption"></div>
                                <div class="gallery-button">
                                    <span class="btn">
                                        <i class="far fa-image"></i>
                                    </span>
                                </div>
                            </a>
                        </div>
                    </div>
                <?php
                endif;
            endforeach;
        ?>

    </div>

    <?php
    }
}

if( !function_exists('business_roy_recentwork')){
    function business_roy_recentwork(){
        business_roy_recentwork_default();
    }
}

add_action('business_roy_action_recentwork', 'business_roy_recentwork', 55);

do_action('business_roy_action_recentwork');