<?php
/**
 * Template part for displaying front page section
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Business Roy
 */
/**
 * Our Main Service Section.
*/
if (! function_exists( 'business_roy_service' ) ):

    function business_roy_service(){

        $super_title    = get_theme_mod('business_roy_service_super_title');
        $title          = get_theme_mod('business_roy_service_title');
        $title_style    = get_theme_mod( 'business_roy_service_title_align', 'text-center');

        $service_type = get_theme_mod('business_roy_service_type','default');

        $service_layout = get_theme_mod('business_roy_service_layout', 'style1');
       
        $services_options = get_theme_mod('business_roy_service_service_section','disable');
        if( !empty( $services_options ) && $services_options == 'enable' ){
            $service_class = array(
                'section',
                'service-section',
                $service_layout
            );
            ?>
            <section id="service-section" class="<?php echo esc_attr(implode(' ', $service_class)) ?>">
                <?php business_roy_add_top_seperator('service'); ?>
                <div class="section-wrap">
                    <div class="container-fluid">
                        <div class="inner-section-wrap">
                            <?php business_roy_section_title( $super_title, $title, $title_style ); ?>
                            <?php
                                if( !empty( $service_type ) && $service_type == 'advance' ){
                                    if( $service_layout == 'style2'){
                                        get_business_roy_service_advance_layout2(); 
                                    }else{
                                        get_business_roy_service_advance_content($service_layout);
                                    }
                                }else{
                                    if( $service_layout == 'style2'){
                                        get_business_roy_service_layout2(); 
                                    }else{
                                        get_business_roy_service_default_content($service_layout);
                                    }
                                }
                            ?>
                        </div>
                    </div>
                </div>
                <?php business_roy_add_bottom_seperator('service'); ?>
            </section>
    <?php } }
endif;
add_action('business_roy_action_service', 'business_roy_service', 45);


/** LAYOUT ONE *************** */


/******
 * Default Service Layout One
 */
if (! function_exists( 'get_business_roy_left_services' ) ):
    function get_business_roy_left_services($array){ 
        $btn = get_theme_mod('business_roy_service_button', __("Read More", 'business-roy'));
        ?>
        <div class="left_data feature_box">
            <?php foreach($array as $page): ?>
                <div class="data_block" data-aos="fade-up" data-aos-duration="1500">
                    <div class="text">
                        <h4><a href="<?php echo esc_url( get_the_permalink($page->service_page) ); ?>"><?php echo esc_html( get_the_title($page->service_page) ); ?></a></h4>
                        <p><?php echo esc_html( get_the_excerpt( $page->service_page ) ); ?></p>
                        <?php if($btn): ?>
                            <a href="<?php echo esc_url( get_the_permalink($page->service_page) ); ?>" class="btn btn-noborder">
                                <?php echo esc_html( $btn ); ?> <i class="fas fa-long-arrow-alt-right"></i>
                            </a>
                        <?php endif; ?>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        <?php
    }
endif; 

if (! function_exists( 'get_business_roy_right_services' ) ):
    function get_business_roy_right_services($array){ 
        $btn = get_theme_mod('business_roy_service_button', __("Read More", 'business-roy'));
        ?>
        <div class="right_data feature_box">
            <?php foreach($array as $page): ?>
                <div class="data_block" data-aos="fade-up" data-aos-duration="1500">
                    <div class="text">
                        <h4><a href="<?php echo esc_url( get_the_permalink($page->service_page) ); ?>"><?php echo esc_html( get_the_title($page->service_page) ); ?></a></h4>
                        <p><?php echo esc_html( get_the_excerpt( $page->service_page ) ); ?></p>
                        <?php if($btn): ?>
                            <a href="<?php echo esc_url( get_the_permalink($page->service_page) ); ?>" class="btn btn-noborder">
                                <?php echo esc_html( $btn ); ?> <i class="fas fa-long-arrow-alt-right"></i>
                            </a>
                        <?php endif; ?>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        <?php
    }
endif; 

if (! function_exists( 'get_business_roy_service_default_content' ) ):

    function get_business_roy_service_default_content($service_layout){

        $service_page   = get_theme_mod('business_roy_service');

        if( $service_page ){
            $pages = json_decode($service_page);
        }
        if( $service_page):
            $leftArray = $rightArray = array();
            if( $pages && is_array($pages) && count($pages) > 1 && ($pages[0]->service_page)){
                list($leftArray, $rightArray) = array_chunk($pages, ceil(count($pages) / 2));
            }else{
                $leftArray = $pages;
            }
            ?>
            <div class="service-wrapper">
                <div class="feature_detail">

                    <?php get_business_roy_left_services( $leftArray); ?>

                    <?php
                        $img = get_theme_mod('business_roy_service_bg_url');
                        if( !empty( $img ) ): 
                    ?>
                        <div class="feature_img">
                            <img src="<?php echo esc_url($img); ?>" alt="image"  data-aos="fade-up" data-aos-duration="1500" data-aos-delay="100">
                        </div>
                    <?php endif; ?>

                    <?php get_business_roy_right_services( $rightArray); ?>

                </div>
            </div>
            <?php
        endif;
    }
endif;

/******
 * Advance Service Layout One
*/
if (! function_exists( 'get_business_roy_service_advance_content' ) ):

    function get_business_roy_service_advance_content($service_layout){

        $service_page  = get_theme_mod('business_roy_service_advance_settings');

        if( $service_page ){
            $pages = json_decode($service_page);
        }
        if( $service_page):
            $leftArray = $rightArray = array();
            if( $pages && is_array($pages) && count($pages) > 1 && ($pages[0]->block_title)){
                list($leftArray, $rightArray) = array_chunk($pages, ceil(count($pages) / 2));
            }else{
                $leftArray = $pages;
            }
            ?>
            <div class="service-wrapper">
                <div class="feature_detail">
                    <div class="left_data feature_box">
                        <?php foreach($leftArray as $page): ?>
                            <div class="data_block" data-aos="fade-up" data-aos-duration="1500">
                                <div class="text">
                                    <h4><a href="<?php echo esc_url( $page->button_url ); ?>"><?php echo esc_html( $page->block_title ); ?></a></h4>
                                    <p><?php echo esc_html( $page->block_desc ); ?></p>
                                    <?php if($page->button_text): ?>
                                        <a href="<?php echo esc_url( $page->button_url ); ?>" class="btn btn-noborder">
                                            <?php echo esc_html( $page->button_text ); ?> <i class="fas fa-long-arrow-alt-right"></i>
                                        </a>
                                    <?php endif; ?>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>

                    <?php
                        $img = get_theme_mod('business_roy_service_bg_url');
                        if( !empty( $img ) ): 
                    ?>
                        <div class="feature_img">
                            <img src="<?php echo esc_url($img); ?>" alt="image"  data-aos="fade-up" data-aos-duration="1500" data-aos-delay="100">
                        </div>
                    <?php endif; ?>
                    
                    <div class="right_data feature_box">
                        <?php foreach($rightArray as $page): ?>
                            <div class="data_block" data-aos="fade-up" data-aos-duration="1500">
                                <div class="text">
                                    <h4><a href="<?php echo esc_url( $page->button_url ); ?>"><?php echo esc_html( $page->block_title ); ?></a></h4>
                                    <p><?php echo esc_html( $page->block_desc ); ?></p>
                                    <?php if($page->button_text): ?>
                                        <a href="<?php echo esc_url( $page->button_url ); ?>" class="btn btn-noborder">
                                            <?php echo esc_html( $page->button_text ); ?> <i class="fas fa-long-arrow-alt-right"></i>
                                        </a>
                                    <?php endif; ?>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>

                </div>
            </div>
            <?php
        endif;
    }
endif;


/** LAYOUT TWO *************** */

/******
 * Default Service Layout 2 (two)
 */
if( !function_exists("get_business_roy_service_layout2")){

    function get_business_roy_service_layout2(){
        
        $service_page   = get_theme_mod('business_roy_service');
        $btn = get_theme_mod('business_roy_service_button', __("Read More", 'business-roy'));
        
        if( $service_page ){
            $pages = json_decode($service_page);  
        }
        if( $service_page):
        ?>
            <div class="d-grid d-grid-column-3" data-aos="fade-up" data-aos-duration="1500">
                <?php foreach($pages as $page): ?>
                    <div class="service-block text-center">
                        <figure>
                            <a href="<?php echo esc_url( get_the_permalink($page->service_page) ); ?>">
                                <?php echo get_the_post_thumbnail($page->service_page, 'medium_large'); ?>
                            </a>
                        </figure>
                        <div class="bottom-content">
                            <?php if( $page->icon ): ?>
                                <div class="icon-box">
                                    <i class="<?php echo esc_attr($page->icon); ?>"></i>
                                </div>
                            <?php endif; ?>
                            <h4><a href="<?php echo esc_url( get_the_permalink($page->service_page) ); ?>"><?php echo esc_html( get_the_title($page->service_page) ); ?></a></h4>
                            <p><?php echo esc_html( get_the_excerpt( $page->service_page ) ); ?></p>
                            <?php if($btn): ?>
                                <a href="<?php echo esc_url( get_the_permalink($page->service_page) ); ?>" class="btn btn-noborder">
                                    <?php echo esc_html( $btn ); ?> <i class="fas fa-long-arrow-alt-right"></i>
                                </a>
                            <?php endif; ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php
        endif;

    }
}

/******
 * Advance Service Layout 2 (two)
 */
if( !function_exists("get_business_roy_service_advance_layout2")){

    function get_business_roy_service_advance_layout2(){
        
        $service_page   = get_theme_mod('business_roy_service_advance_settings');

        if( $service_page ){
            $pages = json_decode($service_page);  
        }
        if( $service_page):
        ?>
            <div class="d-grid d-grid-column-3" data-aos="fade-up" data-aos-duration="1500">
                <?php foreach($pages as $page): ?>
                    <div class="service-block text-center">
                        <figure>
                            <a href="<?php echo esc_url( $page->button_url ); ?>">
                                <?php
                                    $attachment_id = attachment_url_to_postid( $page->block_image );
                                    if( $attachment_id){
                                        $img = wp_get_attachment_image_url( $attachment_id, 'medium_large' );
                                    }else{
                                        $img = $page->block_image;
                                    }

                                    if( $img ) {
                                        echo '<img src="'. esc_url($img ). '" alt="'. $page->block_title .'"/>';       
                                    } 
                                ?>
                            </a>
                        </figure>
                        <div class="bottom-content">
                            <?php if( $page->block_icon ): ?>
                                <div class="icon-box">
                                    <i class="<?php echo esc_attr($page->block_icon); ?>"></i>
                                </div>
                            <?php endif; ?>
                            <h4><a href="<?php echo esc_url( $page->button_url ); ?>"><?php echo esc_html( $page->block_title ); ?></a></h4>
                            <p><?php echo esc_html( $page->block_desc ); ?></p>
                            <?php if($page->button_text): ?>
                                <a href="<?php echo esc_url( $page->button_url ); ?>" class="btn btn-noborder">
                                    <?php echo esc_html( $page->button_text ); ?> <i class="fas fa-long-arrow-alt-right"></i>
                                </a>
                            <?php endif; ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php
        endif;

    }
}

do_action('business_roy_action_service');
