<?php
/**
 * Template part for displaying front page section
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Business Roy
 */
/**
 *  Our Team Member Section
*/
if (! function_exists( 'business_roy_team' ) ):

    function business_roy_team(){

        $team_options = get_theme_mod('business_roy_team_options','disable');

        if( !empty( $team_options ) && $team_options == 'enable' ){

            $team_layout    = get_theme_mod('business_roy_team_style', 'style1');
            $team_page      = get_theme_mod('business_roy_team');
            $team_col       = get_theme_mod( 'business_roy_team_col', 3 );
        ?>
        <section id="team-section" class="team-section section <?php echo esc_attr( $team_layout ); ?>">
            <?php business_roy_add_top_seperator('team'); ?>
            <div class="section-wrap">
                <div class="container">
                    <div class="inner-section-wrap">
                        <?php 
                            /**
                             * Section Title
                            */
                            $supertitle = get_theme_mod( 'business_roy_team_super_title' );
                            $title 		= get_theme_mod( 'business_roy_team_title' );
                            $titlestyle = get_theme_mod( 'business_roy_team_title_align','text-center' );
                            business_roy_section_title( $supertitle, $title, $titlestyle ); 
                        ?>
                        <div class="d-grid d-grid-column-<?php echo esc_attr($team_col); ?> team-wrapper">
                            <?php
                                $team_page = get_theme_mod('business_roy_team');
                                if (!empty( $team_page ) ):
                                $team_pages = json_decode($team_page);
                                foreach ($team_pages as $team_page):
                                    $page_id = $team_page->team_page;
                                    if (!empty( $page_id )):
                                    $team_query = new WP_Query('page_id=' . $page_id);
                                    if ($team_query->have_posts()): while ($team_query->have_posts()): $team_query->the_post();
                            ?>
                                <div class="team-item" data-aos="fade-up" data-aos-duration="1500" data-aos-delay="100">
                                    <div class="box box-shadow">
                                        <figure>
                                            <?php
                                                if( !empty( $team_layout ) && $team_layout == 'style2') {
                                                    the_post_thumbnail('thumbnail');
                                                } else {
                                                    the_post_thumbnail('medium_large');
                                                }
                                            ?>
                                        </figure>
                                        <div class="team-wrap <?php echo esc_attr($titlestyle); ?>">
                                            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                            <?php if (!empty( $team_page->designation ) ): ?>
                                                <span class="designation"><?php echo esc_html($team_page->designation); ?></span>
                                            <?php endif; ?>
                                            <?php if( !empty( $team_layout ) && $team_layout == 'style2' ) { the_excerpt(); } ?>
                                            <ul class="sp_socialicon">
                                                <?php if (!empty( $team_page->facebook ) ) : ?>
                                                    <li>
                                                        <a href="<?php echo esc_url( $team_page->facebook ); ?>">
                                                            <i class="fab fa-facebook-f"></i>
                                                        </a>
                                                    </li>
                                                <?php endif; if (!empty( $team_page->twitter ) ) : ?>
                                                    <li>
                                                        <a href="<?php echo esc_url($team_page->twitter); ?>">
                                                            <i class="fab fa-twitter"></i>
                                                        </a>
                                                    </li>
                                                <?php endif; if (!empty( $team_page->linkedin ) ) : ?>
                                                    <li>
                                                        <a href="<?php echo esc_url($team_page->linkedin); ?>">
                                                            <i class="fab fa-linkedin-in"></i>
                                                        </a>
                                                    </li>
                                                <?php endif; if (!empty( $team_page->instagram ) ) : ?>
                                                    <li>
                                                        <a href="<?php echo esc_url($team_page->instagram); ?>">
                                                            <i class="fab fa-instagram"></i>
                                                        </a>
                                                    </li>
                                                <?php endif; ?>
                                            </ul>
                                        </div>
                                    </div>
                                </div>
                                <?php endwhile; endif; endif; endforeach; endif; ?>
                        </div>
                    </div>
                </div>
            </div>
            <?php business_roy_add_bottom_seperator('team'); ?>
        </section>
    <?php } }
endif;
add_action('business_roy_action_team', 'business_roy_team', 75);

/**
 * Hook -  business_roy_action_team
 *
 * @hooked business_roy_team - 75
 */
do_action('business_roy_action_team');